@@ -24,8 +24,6 @@
  */
 
 module jdk.internal.vm.compiler {
-    // source file: file:///build/java-openjdk/src/jdk13u-jdk-13.0.2+8/src/jdk.internal.vm.compiler/share/classes/module-info.java
-    //              file:///build/java-openjdk/src/jdk13u-jdk-13.0.2+8/build/linux-aarch64-server-release/support/gensrc/jdk.internal.vm.compiler/module-info.java.extra
     requires java.instrument;
     requires java.management;
     requires jdk.internal.vm.ci;
@@ -106,22 +104,16 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.hotspot.amd64.AMD64HotSpotBackendFactory,
         org.graalvm.compiler.hotspot.sparc.SPARCHotSpotBackendFactory;
     provides org.graalvm.compiler.nodes.graphbuilderconf.NodeIntrinsicPluginFactory with
+        org.graalvm.compiler.hotspot.PluginFactory_HotSpotBackend,
         org.graalvm.compiler.hotspot.amd64.PluginFactory_AMD64X87MathIntrinsicNode,
         org.graalvm.compiler.hotspot.amd64.PluginFactory_AMD64X87MathSnippets,
-        org.graalvm.compiler.hotspot.nodes.aot.PluginFactory_EncodedSymbolNode,
-        org.graalvm.compiler.hotspot.nodes.aot.PluginFactory_InitializeKlassStubCall,
-        org.graalvm.compiler.hotspot.nodes.aot.PluginFactory_LoadConstantIndirectlyFixedNode,
-        org.graalvm.compiler.hotspot.nodes.aot.PluginFactory_LoadConstantIndirectlyNode,
-        org.graalvm.compiler.hotspot.nodes.aot.PluginFactory_LoadMethodCountersIndirectlyNode,
-        org.graalvm.compiler.hotspot.nodes.aot.PluginFactory_ResolveConstantStubCall,
-        org.graalvm.compiler.hotspot.nodes.aot.PluginFactory_ResolveDynamicStubCall,
-        org.graalvm.compiler.hotspot.nodes.aot.PluginFactory_ResolveMethodAndLoadCountersStubCall,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_AcquiredCASLockNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_AllocaNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_BeginLockScopeNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_CurrentJavaThreadNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_CurrentLockNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_DeoptimizeCallerNode,
+        org.graalvm.compiler.hotspot.nodes.PluginFactory_DeoptimizeWithExceptionInCallerNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_DimensionsNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_EndLockScopeNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_FastAcquireBiasedLockNode,
@@ -131,27 +123,34 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.hotspot.nodes.PluginFactory_MonitorCounterNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_PatchReturnAddressNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_VMErrorNode,
-        org.graalvm.compiler.hotspot.PluginFactory_HotSpotBackend,
+        org.graalvm.compiler.hotspot.nodes.aot.PluginFactory_EncodedSymbolNode,
+        org.graalvm.compiler.hotspot.nodes.aot.PluginFactory_InitializeKlassStubCall,
+        org.graalvm.compiler.hotspot.nodes.aot.PluginFactory_LoadConstantIndirectlyFixedNode,
+        org.graalvm.compiler.hotspot.nodes.aot.PluginFactory_LoadConstantIndirectlyNode,
+        org.graalvm.compiler.hotspot.nodes.aot.PluginFactory_LoadMethodCountersIndirectlyNode,
+        org.graalvm.compiler.hotspot.nodes.aot.PluginFactory_ResolveConstantStubCall,
+        org.graalvm.compiler.hotspot.nodes.aot.PluginFactory_ResolveDynamicStubCall,
+        org.graalvm.compiler.hotspot.nodes.aot.PluginFactory_ResolveMethodAndLoadCountersStubCall,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_AESCryptSubstitutions,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_AssertionSnippets,
+        org.graalvm.compiler.hotspot.replacements.PluginFactory_CRC32CSubstitutions,
+        org.graalvm.compiler.hotspot.replacements.PluginFactory_CRC32Substitutions,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_CipherBlockChainingSubstitutions,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_ClassGetHubNode,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_CounterModeSubstitutions,
-        org.graalvm.compiler.hotspot.replacements.PluginFactory_CRC32CSubstitutions,
-        org.graalvm.compiler.hotspot.replacements.PluginFactory_CRC32Substitutions,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_DigestBaseSubstitutions,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_HotSpotClassSubstitutions,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_HotSpotReplacementsUtil,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_HubGetClassNode,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_IdentityHashCodeNode,
+        org.graalvm.compiler.hotspot.replacements.PluginFactory_Log,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_MonitorSnippets,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_NewObjectSnippets,
-        org.graalvm.compiler.hotspot.replacements.PluginFactory_ObjectSubstitutions,
+        org.graalvm.compiler.hotspot.replacements.PluginFactory_ObjectSnippets,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_SHA2Substitutions,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_SHA5Substitutions,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_SHASubstitutions,
-        org.graalvm.compiler.hotspot.replacements.PluginFactory_ThreadSubstitutions,
-        org.graalvm.compiler.hotspot.replacements.PluginFactory_WriteBarrierSnippets,
+        org.graalvm.compiler.hotspot.replacements.PluginFactory_UnsafeCopyMemoryNode,
         org.graalvm.compiler.hotspot.replacements.profiling.PluginFactory_ProbabilisticProfileSnippets,
         org.graalvm.compiler.hotspot.replacements.profiling.PluginFactory_ProfileSnippets,
         org.graalvm.compiler.hotspot.stubs.PluginFactory_CreateExceptionStub,
@@ -159,6 +158,16 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.hotspot.stubs.PluginFactory_ForeignCallSnippets,
         org.graalvm.compiler.hotspot.stubs.PluginFactory_StubUtil,
         org.graalvm.compiler.hotspot.stubs.PluginFactory_UnwindExceptionToCallerStub,
+        org.graalvm.compiler.nodes.PluginFactory_BreakpointNode,
+        org.graalvm.compiler.nodes.PluginFactory_ComputeObjectAddressNode,
+        org.graalvm.compiler.nodes.PluginFactory_ConstantNode,
+        org.graalvm.compiler.nodes.PluginFactory_DeoptimizeNode,
+        org.graalvm.compiler.nodes.PluginFactory_GetObjectAddressNode,
+        org.graalvm.compiler.nodes.PluginFactory_PauseNode,
+        org.graalvm.compiler.nodes.PluginFactory_PiArrayNode,
+        org.graalvm.compiler.nodes.PluginFactory_PiNode,
+        org.graalvm.compiler.nodes.PluginFactory_PrefetchAllocateNode,
+        org.graalvm.compiler.nodes.PluginFactory_SnippetAnchorNode,
         org.graalvm.compiler.nodes.debug.PluginFactory_DynamicCounterNode,
         org.graalvm.compiler.nodes.extended.PluginFactory_BranchProbabilityNode,
         org.graalvm.compiler.nodes.extended.PluginFactory_FixedValueAnchorNode,
@@ -174,22 +183,19 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.nodes.java.PluginFactory_InstanceOfNode,
         org.graalvm.compiler.nodes.java.PluginFactory_NewArrayNode,
         org.graalvm.compiler.nodes.java.PluginFactory_RegisterFinalizerNode,
-        org.graalvm.compiler.nodes.memory.address.PluginFactory_OffsetAddressNode,
         org.graalvm.compiler.nodes.memory.PluginFactory_MemoryAnchorNode,
-        org.graalvm.compiler.nodes.PluginFactory_BreakpointNode,
-        org.graalvm.compiler.nodes.PluginFactory_ComputeObjectAddressNode,
-        org.graalvm.compiler.nodes.PluginFactory_ConstantNode,
-        org.graalvm.compiler.nodes.PluginFactory_DeoptimizeNode,
-        org.graalvm.compiler.nodes.PluginFactory_GetObjectAddressNode,
-        org.graalvm.compiler.nodes.PluginFactory_PauseNode,
-        org.graalvm.compiler.nodes.PluginFactory_PiArrayNode,
-        org.graalvm.compiler.nodes.PluginFactory_PiNode,
-        org.graalvm.compiler.nodes.PluginFactory_PrefetchAllocateNode,
-        org.graalvm.compiler.nodes.PluginFactory_SnippetAnchorNode,
+        org.graalvm.compiler.nodes.memory.address.PluginFactory_OffsetAddressNode,
+        org.graalvm.compiler.replacements.PluginFactory_ConstantStringIndexOfSnippets,
+        org.graalvm.compiler.replacements.PluginFactory_ReplacementsUtil,
+        org.graalvm.compiler.replacements.PluginFactory_SnippetCounterNode,
         org.graalvm.compiler.replacements.aarch64.PluginFactory_AArch64FloatArithmeticSnippets,
         org.graalvm.compiler.replacements.aarch64.PluginFactory_AArch64IntegerArithmeticSnippets,
+        org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64ArrayIndexOfDispatchNode,
         org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64ArrayIndexOfNode,
-        org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64ArrayIndexOf,
+        org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64CountLeadingZerosNode,
+        org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64CountTrailingZerosNode,
+        org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64IntegerSubstitutions,
+        org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64LongSubstitutions,
         org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64StringLatin1InflateNode,
         org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64StringLatin1Substitutions,
         org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64StringSubstitutions,
@@ -199,6 +205,7 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.replacements.arraycopy.PluginFactory_ArrayCopyWithDelayedLoweringNode,
         org.graalvm.compiler.replacements.arraycopy.PluginFactory_CheckcastArrayCopyCallNode,
         org.graalvm.compiler.replacements.arraycopy.PluginFactory_GenericArrayCopyCallNode,
+        org.graalvm.compiler.replacements.gc.PluginFactory_G1WriteBarrierSnippets,
         org.graalvm.compiler.replacements.nodes.PluginFactory_ArrayCompareToNode,
         org.graalvm.compiler.replacements.nodes.PluginFactory_ArrayEqualsNode,
         org.graalvm.compiler.replacements.nodes.PluginFactory_ArrayRegionEqualsNode,
@@ -207,20 +214,15 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.replacements.nodes.PluginFactory_BitScanForwardNode,
         org.graalvm.compiler.replacements.nodes.PluginFactory_BitScanReverseNode,
         org.graalvm.compiler.replacements.nodes.PluginFactory_CStringConstant,
-        org.graalvm.compiler.replacements.nodes.PluginFactory_DirectStoreNode,
         org.graalvm.compiler.replacements.nodes.PluginFactory_ExplodeLoopNode,
         org.graalvm.compiler.replacements.nodes.PluginFactory_UnaryMathIntrinsicNode,
-        org.graalvm.compiler.replacements.nodes.PluginFactory_ZeroMemoryNode,
-        org.graalvm.compiler.replacements.PluginFactory_ConstantStringIndexOfSnippets,
-        org.graalvm.compiler.replacements.PluginFactory_Log,
-        org.graalvm.compiler.replacements.PluginFactory_ReplacementsUtil,
-        org.graalvm.compiler.replacements.PluginFactory_SnippetCounterNode;
+        org.graalvm.compiler.replacements.nodes.PluginFactory_ZeroMemoryNode;
     provides org.graalvm.compiler.options.OptionDescriptors with
+        org.graalvm.compiler.core.GraalCompilerOptions_OptionDescriptors,
         org.graalvm.compiler.core.common.GraalOptions_OptionDescriptors,
         org.graalvm.compiler.core.common.SpeculativeExecutionAttacksMitigations_OptionDescriptors,
         org.graalvm.compiler.core.common.spi.JavaConstantFieldProvider_OptionDescriptors,
         org.graalvm.compiler.core.common.util.CompilationAlarm_OptionDescriptors,
-        org.graalvm.compiler.core.GraalCompilerOptions_OptionDescriptors,
         org.graalvm.compiler.core.phases.HighTier_OptionDescriptors,
         org.graalvm.compiler.core.phases.LowTier_OptionDescriptors,
         org.graalvm.compiler.debug.Assertions_OptionDescriptors,
@@ -231,18 +233,20 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.hotspot.CompilationStatistics_OptionDescriptors,
         org.graalvm.compiler.hotspot.CompilationWatchDog_OptionDescriptors,
         org.graalvm.compiler.hotspot.CompilerConfigurationFactory_OptionDescriptors,
-        org.graalvm.compiler.hotspot.debug.BenchmarkCounters_OptionDescriptors,
         org.graalvm.compiler.hotspot.HotSpotBackend_OptionDescriptors,
         org.graalvm.compiler.hotspot.HotSpotCompiledCodeBuilder_OptionDescriptors,
         org.graalvm.compiler.hotspot.HotSpotGraalCompilerFactory_OptionDescriptors,
         org.graalvm.compiler.hotspot.HotSpotTTYStreamProvider_OptionDescriptors,
+        org.graalvm.compiler.hotspot.debug.BenchmarkCounters_OptionDescriptors,
         org.graalvm.compiler.hotspot.meta.HotSpotAOTProfilingPlugin_OptionDescriptors,
+        org.graalvm.compiler.hotspot.meta.HotSpotNodePlugin_OptionDescriptors,
         org.graalvm.compiler.hotspot.meta.HotSpotProfilingPlugin_OptionDescriptors,
         org.graalvm.compiler.hotspot.nodes.profiling.ProfileNode_OptionDescriptors,
-        org.graalvm.compiler.hotspot.phases.aot.AOTInliningPolicy_OptionDescriptors,
         org.graalvm.compiler.hotspot.phases.OnStackReplacementPhase_OptionDescriptors,
+        org.graalvm.compiler.hotspot.phases.aot.AOTInliningPolicy_OptionDescriptors,
         org.graalvm.compiler.hotspot.phases.profiling.FinalizeProfileNodesPhase_OptionDescriptors,
         org.graalvm.compiler.hotspot.replacements.HotspotSnippetsOptions_OptionDescriptors,
+        org.graalvm.compiler.hotspot.stubs.CreateExceptionStub_OptionDescriptors,
         org.graalvm.compiler.hotspot.stubs.StubOptions_OptionDescriptors,
         org.graalvm.compiler.java.BytecodeParserOptions_OptionDescriptors,
         org.graalvm.compiler.lir.alloc.lsra.LinearScanEliminateSpillMovePhase_OptionDescriptors,
@@ -250,7 +254,6 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.lir.alloc.lsra.OptimizingLinearScanWalker_OptionDescriptors,
         org.graalvm.compiler.lir.amd64.phases.StackMoveOptimizationPhase_OptionDescriptors,
         org.graalvm.compiler.lir.asm.CompilationResultBuilder_OptionDescriptors,
-        org.graalvm.compiler.lir.BailoutAndRestartBackendException_OptionDescriptors,
         org.graalvm.compiler.lir.constopt.ConstantLoadOptimization_OptionDescriptors,
         org.graalvm.compiler.lir.gen.LIRGenerator_OptionDescriptors,
         org.graalvm.compiler.lir.phases.LIRPhase_OptionDescriptors,
@@ -258,12 +261,13 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.lir.profiling.MoveProfilingPhase_OptionDescriptors,
         org.graalvm.compiler.lir.stackslotalloc.LSStackSlotAllocator_OptionDescriptors,
         org.graalvm.compiler.loop.DefaultLoopPolicies_OptionDescriptors,
+        org.graalvm.compiler.loop.LoopPolicies_OptionDescriptors,
         org.graalvm.compiler.nodes.util.GraphUtil_OptionDescriptors,
         org.graalvm.compiler.phases.BasePhase_OptionDescriptors,
         org.graalvm.compiler.phases.common.DeadCodeEliminationPhase_OptionDescriptors,
-        org.graalvm.compiler.phases.common.inlining.InliningPhase_OptionDescriptors,
         org.graalvm.compiler.phases.common.NodeCounterPhase_OptionDescriptors,
         org.graalvm.compiler.phases.common.UseTrappingNullChecksPhase_OptionDescriptors,
+        org.graalvm.compiler.phases.common.inlining.InliningPhase_OptionDescriptors,
         org.graalvm.compiler.printer.NoDeadCodeVerifyHandler_OptionDescriptors,
         org.graalvm.compiler.replacements.PEGraphDecoder_OptionDescriptors,
         org.graalvm.compiler.replacements.SnippetTemplate_OptionDescriptors,
