@@ -30,13 +30,10 @@
  * @since 10
  */
 module jdk.internal.vm.compiler.management {
-    // source file: file:///build/java-openjdk/src/jdk13u-jdk-13.0.2+8/src/jdk.internal.vm.compiler.management/share/classes/module-info.java
-    //              file:///build/java-openjdk/src/jdk13u-jdk-13.0.2+8/build/linux-aarch64-server-release/support/gensrc/jdk.internal.vm.compiler.management/module-info.java.extra
     requires java.management;
     requires jdk.management;
     requires jdk.internal.vm.ci;
     requires jdk.internal.vm.compiler;
 
     provides org.graalvm.compiler.hotspot.HotSpotGraalManagementRegistration with org.graalvm.compiler.hotspot.management.HotSpotGraalManagement;
-    provides org.graalvm.compiler.serviceprovider.JMXService with org.graalvm.compiler.hotspot.management.JMXServiceProvider;
 }
