@@ -43,6 +43,7 @@ import org.graalvm.compiler.phases.OptimisticOptimizations;
 import org.graalvm.compiler.phases.PhaseSuite;
 import org.graalvm.compiler.phases.common.DeadCodeEliminationPhase;
 import org.graalvm.compiler.phases.tiers.HighTierContext;
+import org.graalvm.compiler.serviceprovider.GraalServices;
 import org.junit.Assert;
 import org.junit.Ignore;
 import org.junit.Test;
@@ -182,7 +183,9 @@ public class InliningTest extends GraalCompilerTest {
     public void testClassHierarchyAnalysis() {
         assertInlined(getGraph("invokeLeafClassMethodSnippet", false));
         assertInlined(getGraph("invokeConcreteMethodSnippet", false));
-        assertInlined(getGraph("invokeSingleImplementorInterfaceSnippet", false));
+        if (GraalServices.hasLookupReferencedType()) {
+            assertInlined(getGraph("invokeSingleImplementorInterfaceSnippet", false));
+        }
         // assertInlined(getGraph("invokeConcreteInterfaceMethodSnippet", false));
 
         assertNotInlined(getGraph("invokeOverriddenPublicMethodSnippet", false));
@@ -194,7 +197,9 @@ public class InliningTest extends GraalCompilerTest {
     public void testClassHierarchyAnalysisIP() {
         assertManyMethodInfopoints(assertInlined(getGraph("invokeLeafClassMethodSnippet", true)));
         assertManyMethodInfopoints(assertInlined(getGraph("invokeConcreteMethodSnippet", true)));
-        assertManyMethodInfopoints(assertInlined(getGraph("invokeSingleImplementorInterfaceSnippet", true)));
+        if (GraalServices.hasLookupReferencedType()) {
+            assertManyMethodInfopoints(assertInlined(getGraph("invokeSingleImplementorInterfaceSnippet", true)));
+        }
         //@formatter:off
         // assertInlineInfopoints(assertInlined(getGraph("invokeConcreteInterfaceMethodSnippet", true)));
         //@formatter:on
