@@ -154,14 +154,16 @@ public class FormatData_kea extends ListResourceBundle {
                "T3",
                "T4",
             };
+        final String[] metaValue_QuarterNarrows = new String[] {
+               "1",
+               "2",
+               "3",
+               "4",
+            };
         final String[] metaValue_AmPmMarkers = new String[] {
                "am",
                "pm",
             };
-        final String[] metaValue_narrow_AmPmMarkers = new String[] {
-               "a",
-               "p",
-            };
         final String[] metaValue_Eras = new String[] {
                "AK",
                "DK",
@@ -172,61 +174,56 @@ public class FormatData_kea extends ListResourceBundle {
                "HH:mm:ss",
                "HH:mm",
             };
-        final String[] metaValue_buddhist_QuarterNarrows = new String[] {
-               "1",
-               "2",
-               "3",
-               "4",
-            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE, d 'di' MMMM 'di' y G",
                "d 'di' MMMM 'di' y G",
                "d MMM y G",
-               "d/M/y GGGGG",
+               "dd/MM/y GGGGG",
             };
         final String[] metaValue_buddhist_DatePatterns = new String[] {
                "EEEE, d 'di' MMMM 'di' y GGGG",
                "d 'di' MMMM 'di' y GGGG",
                "d MMM y GGGG",
-               "d/M/y G",
+               "dd/MM/y G",
             };
         final String metaValue_calendarname_gregorian = "Kalend\u00e1riu Gregorianu";
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
-            { "field.year", "Anu" },
+            { "field.year", "anu" },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
-            { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
             { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "timezone.regionFormat.standard", "Ora di {0} (normal)" },
+            { "timezone.regionFormat.standard", "Ora Padron di {0}" },
             { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "calendarname.japanese", "Kalend\u00e1riu japones" },
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "long.Eras",
                 new String[] {
-                    "Antis di Kristu",
-                    "Dispos di Kristu",
+                    "antis di Kristu",
+                    "dispos di Kristu",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
             { "DateTimePatterns",
                 new String[] {
-                    "{1} {0}",
-                    "{1} {0}",
-                    "{1} {0}",
-                    "{1} {0}",
+                    "{1}, {0}",
+                    "{1}, {0}",
+                    "{1}, {0}",
+                    "{1}, {0}",
                 }
             },
-            { "narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "latn.NumberElements",
                 new String[] {
                     ",",
@@ -245,25 +242,21 @@ public class FormatData_kea extends ListResourceBundle {
             { "MonthNarrows", metaValue_MonthNarrows },
             { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
             { "buddhist.DayNames", metaValue_DayNames },
-            { "field.minute", "Minutu" },
+            { "field.minute", "minutu" },
+            { "field.era", "era" },
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "am/pm" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
+            { "calendarname.roc", "Kalend\u00e1riu di Rep\u00fablika di Xina" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "field.month", "Mes" },
-            { "field.second", "Sigundu" },
+            { "field.month", "mes" },
+            { "field.second", "sigundu" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "calendarname.islamic", "Kalend\u00e1riu isl\u00e1miku" },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "Ora di {0}" },
@@ -272,22 +265,21 @@ public class FormatData_kea extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 mil",
-                    "00 mil",
-                    "000 mil",
-                    "0 milh\u00e3u",
-                    "00 milh\u00e3u",
-                    "000 milh\u00e3u",
-                    "0 mil milh\u00e3u",
-                    "00 mil milh\u00e3u",
-                    "000 mil milh\u00e3u",
-                    "0 bilh\u00e3u",
-                    "00 bilh\u00e3u",
-                    "000 bilh\u00e3u",
+                    "{other:0' 'mil}",
+                    "{other:00' 'mil}",
+                    "{other:000' 'mil}",
+                    "{other:0' 'milh\u00e3u}",
+                    "{other:00' 'milh\u00e3u}",
+                    "{other:000' 'milh\u00e3u}",
+                    "{other:0' 'mil' 'milh\u00e3u}",
+                    "{other:00' 'mil' 'milh\u00e3u}",
+                    "{other:000' 'mil' 'milh\u00e3u}",
+                    "{other:0' 'bilh\u00e3u}",
+                    "{other:00' 'bilh\u00e3u}",
+                    "{other:000' 'bilh\u00e3u}",
                 }
             },
-            { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -296,16 +288,17 @@ public class FormatData_kea extends ListResourceBundle {
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
-            { "field.zone", "Ora lokal" },
+            { "field.zone", "ora lokal" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "Eras", metaValue_Eras },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
+            { "QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "field.weekday", "Dia di simana" },
+            { "field.weekday", "dia di simana" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
             { "japanese.QuarterNames", metaValue_QuarterNames },
@@ -315,10 +308,10 @@ public class FormatData_kea extends ListResourceBundle {
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
-            { "field.week", "Simana" },
+            { "field.week", "simana" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
@@ -328,28 +321,28 @@ public class FormatData_kea extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0mil",
-                    "00\u00a0mil",
-                    "000\u00a0mil",
-                    "0\u00a0M",
-                    "00\u00a0M",
-                    "000\u00a0M",
-                    "0\u00a0MM",
-                    "00\u00a0MM",
-                    "000\u00a0MM",
-                    "0\u00a0Bi",
-                    "00\u00a0Bi",
-                    "000\u00a0Bi",
+                    "{other:0\u00a0mil}",
+                    "{other:00\u00a0mil}",
+                    "{other:000\u00a0mil}",
+                    "{other:0\u00a0M}",
+                    "{other:00\u00a0M}",
+                    "{other:000\u00a0M}",
+                    "{other:0\u00a0MM}",
+                    "{other:00\u00a0MM}",
+                    "{other:000\u00a0MM}",
+                    "{other:0\u00a0Bi}",
+                    "{other:00\u00a0Bi}",
+                    "{other:000\u00a0Bi}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
-            { "timezone.regionFormat.daylight", "Ora di {0} (ver\u00e3u)" },
+            { "timezone.regionFormat.daylight", "Ora di Veron di {0}" },
             { "DatePatterns",
                 new String[] {
                     "EEEE, d 'di' MMMM 'di' y",
                     "d 'di' MMMM 'di' y",
                     "d MMM y",
-                    "d/M/y",
+                    "dd/MM/y",
                 }
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
@@ -366,8 +359,17 @@ public class FormatData_kea extends ListResourceBundle {
                     "s\u00e1badu",
                 }
             },
-            { "field.hour", "Ora" },
+            { "field.hour", "ora" },
+            { "calendarname.buddhist", "Kalend\u00e1riu budista" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "#,##0.00\u00a0\u00a4;(#,##0.00\u00a0\u00a4)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
