@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -154,12 +154,18 @@ public class FormatData_lt extends ListResourceBundle {
                "III k.",
                "IV k.",
             };
+        final String[] metaValue_QuarterNarrows = new String[] {
+               "1",
+               "2",
+               "3",
+               "4",
+            };
         final String[] metaValue_AmPmMarkers = new String[] {
                "prie\u0161piet",
                "popiet",
             };
         final String[] metaValue_narrow_AmPmMarkers = new String[] {
-               "pr. p.",
+               "pr.\u00a0p.",
                "pop.",
             };
         final String[] metaValue_Eras = new String[] {
@@ -172,13 +178,7 @@ public class FormatData_lt extends ListResourceBundle {
                "HH:mm:ss",
                "HH:mm",
             };
-        final String[] metaValue_buddhist_QuarterNarrows = new String[] {
-               "1",
-               "2",
-               "3",
-               "4",
-            };
-        final String[] metaValue_buddhist_long_Eras = new String[] {
+        final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "BE",
             };
@@ -194,11 +194,27 @@ public class FormatData_lt extends ListResourceBundle {
                "y MMM d GGGG",
                "y-MM-dd GGGG",
             };
-        final String[] metaValue_roc_long_Eras = new String[] {
+        final String[] metaValue_java_time_japanese_long_Eras = new String[] {
+               "po Kristaus",
+               "Meid\u017ei",
+               "Tai\u0161o",
+               "\u0160ova",
+               "Heisei",
+               "Reiwa",
+            };
+        final String[] metaValue_java_time_japanese_Eras = new String[] {
+               "po Kr.",
+               "Meid\u017ei",
+               "Tai\u0161o",
+               "\u0160ova",
+               "Heisei",
+               "Reiwa",
+            };
+        final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "Prie\u0161 R.O.C.",
                "R.O.C.",
             };
-        final String[] metaValue_islamic_long_Eras = new String[] {
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
                "",
                "AH",
             };
@@ -208,7 +224,7 @@ public class FormatData_lt extends ListResourceBundle {
             { "field.year", "metai" },
             { "calendarname.islamic-umalqura", "Islamo kalendorius (Umm al-Qura)" },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.narrow.Eras", metaValue_buddhist_long_Eras },
+            { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations",
@@ -225,7 +241,7 @@ public class FormatData_lt extends ListResourceBundle {
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
-            { "roc.long.Eras", metaValue_roc_long_Eras },
+            { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "timezone.regionFormat.standard", "\u017diemos laikas: {0}" },
             { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
@@ -233,12 +249,14 @@ public class FormatData_lt extends ListResourceBundle {
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "long.Eras",
                 new String[] {
                     "prie\u0161 Krist\u0173",
                     "po Kristaus",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -270,84 +288,135 @@ public class FormatData_lt extends ListResourceBundle {
             { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "minut\u0117" },
+            { "japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
             { "field.era", "era" },
-            { "japanese.long.Eras",
-                new String[] {
-                    "po Kristaus",
-                    "Meid\u017ei",
-                    "Tai\u0161o",
-                    "\u0160ova",
-                    "Heisei",
-                }
-            },
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "iki piet\u0173 / po piet\u0173" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
             { "calendarname.roc", "Kinijos Respublikos kalendorius" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "islamic.Eras", metaValue_islamic_long_Eras },
+            { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "field.month", "m\u0117nuo" },
-            { "roc.Eras", metaValue_roc_long_Eras },
+            { "java.time.japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
+            { "roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.second", "sekund\u0117" },
-            { "DayAbbreviations", metaValue_DayAbbreviations },
-            { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
+            { "islamic.MonthNarrows",
                 new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0\u00a0%",
+                    "1",
+                    "2",
+                    "3",
+                    "4",
+                    "5",
+                    "6",
+                    "7",
+                    "8",
+                    "9",
+                    "10",
+                    "11",
+                    "12",
+                    "",
                 }
             },
+            { "DayAbbreviations", metaValue_DayAbbreviations },
+            { "DayNarrows", metaValue_DayNarrows },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "islamo kalendorius" },
+            { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "Laikas: {0}" },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "{one:0' 't\u016bkstantis few:0' 't\u016bkstan\u010diai many:0' 't\u016bkstan\u010dio other:0' 't\u016bkstan\u010di\u0173}",
+                    "{one:00' 't\u016bkstantis few:00' 't\u016bkstan\u010diai many:00' 't\u016bkstan\u010dio other:00' 't\u016bkstan\u010di\u0173}",
+                    "{one:000' 't\u016bkstantis few:000' 't\u016bkstan\u010diai many:000' 't\u016bkstan\u010dio other:000' 't\u016bkstan\u010di\u0173}",
+                    "{one:0' 'milijonas few:0' 'milijonai many:0' 'milijono other:0' 'milijon\u0173}",
+                    "{one:00' 'milijonas few:00' 'milijonai many:00' 'milijono other:00' 'milijon\u0173}",
+                    "{one:000' 'milijonas few:000' 'milijonai many:000' 'milijono other:000' 'milijon\u0173}",
+                    "{one:0' 'milijardas few:0' 'milijardai many:0' 'milijardo other:0' 'milijard\u0173}",
+                    "{one:00' 'milijardas few:00' 'milijardai many:00' 'milijardo other:00' 'milijard\u0173}",
+                    "{one:000' 'milijardas few:000' 'milijardai many:000' 'milijardo other:000' 'milijard\u0173}",
+                    "{one:0' 'trilijonas few:0' 'trilijonai many:0' 'trilijono other:0' 'trilijon\u0173}",
+                    "{one:00' 'trilijonas few:00' 'trilijonai many:00' 'trilijono other:00' 'trilijon\u0173}",
+                    "{one:000' 'trilijonas few:000' 'trilijonai many:000' 'trilijono other:000' 'trilijon\u0173}",
+                }
+            },
+            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
+            { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.long.Eras", metaValue_buddhist_long_Eras },
+            { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
+            { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.zone", "laiko juosta" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.narrow.Eras", metaValue_roc_long_Eras },
+            { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "Eras", metaValue_Eras },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
+            { "QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "field.weekday", "savait\u0117s diena" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
-            { "islamic.long.Eras", metaValue_islamic_long_Eras },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "java.time.buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "timezone.hourFormat", "+HH:mm;\u2212HH:mm" },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "java.time.japanese.Eras", metaValue_java_time_japanese_Eras },
             { "roc.MonthNames", metaValue_MonthNames },
-            { "buddhist.Eras", metaValue_buddhist_long_Eras },
+            { "buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "field.week", "savait\u0117" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "short.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "{one:0\u00a0t\u016bkst'.' few:0\u00a0t\u016bkst'.' many:0\u00a0t\u016bkst'.' other:0\u00a0t\u016bkst'.'}",
+                    "{one:00\u00a0t\u016bkst'.' few:00\u00a0t\u016bkst'.' many:00\u00a0t\u016bkst'.' other:00\u00a0t\u016bkst'.'}",
+                    "{one:000\u00a0t\u016bkst'.' few:000\u00a0t\u016bkst'.' many:000\u00a0t\u016bkst'.' other:000\u00a0t\u016bkst'.'}",
+                    "{one:0\u00a0mln'.' few:0\u00a0mln'.' many:0\u00a0mln'.' other:0\u00a0mln'.'}",
+                    "{one:00\u00a0mln'.' few:00\u00a0mln'.' many:00\u00a0mln'.' other:00\u00a0mln'.'}",
+                    "{one:000\u00a0mln'.' few:000\u00a0mln'.' many:000\u00a0mln'.' other:000\u00a0mln'.'}",
+                    "{one:0\u00a0mlrd'.' few:0\u00a0mlrd'.' many:0\u00a0mlrd'.' other:0\u00a0mlrd'.'}",
+                    "{one:00\u00a0mlrd'.' few:00\u00a0mlrd'.' many:00\u00a0mlrd'.' other:00\u00a0mlrd'.'}",
+                    "{one:000\u00a0mlrd'.' few:000\u00a0mlrd'.' many:000\u00a0mlrd'.' other:000\u00a0mlrd'.'}",
+                    "{one:0\u00a0trln'.' few:0\u00a0trln'.' many:0\u00a0trln'.' other:0\u00a0trln'.'}",
+                    "{one:00\u00a0trln'.' few:00\u00a0trln'.' many:00\u00a0trln'.' other:00\u00a0trln'.'}",
+                    "{one:000\u00a0trln'.' few:000\u00a0trln'.' many:000\u00a0trln'.' other:000\u00a0trln'.'}",
+                }
+            },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "java.time.buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "timezone.regionFormat.daylight", "Vasaros laikas: {0}" },
             { "DatePatterns",
                 new String[] {
@@ -362,7 +431,7 @@ public class FormatData_lt extends ListResourceBundle {
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "valanda" },
-            { "islamic.narrow.Eras", metaValue_islamic_long_Eras },
+            { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "budist\u0173 kalendorius" },
             { "standalone.MonthNames",
                 new String[] {
@@ -381,20 +450,21 @@ public class FormatData_lt extends ListResourceBundle {
                     "",
                 }
             },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0\u00a0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "japanese.Eras",
-                new String[] {
-                    "po Kr.",
-                    "Meid\u017ei",
-                    "Tai\u0161o",
-                    "\u0160ova",
-                    "Heisei",
-                }
-            },
+            { "japanese.Eras", metaValue_java_time_japanese_Eras },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
