@@ -78,7 +78,7 @@ public class FormatData_ps extends ListResourceBundle {
                "\u0645\u06cd",
                "\u062c\u0648\u0646",
                "\u062c\u0648\u0644\u0627\u06cc",
-               "\u0627\u06af\u0633\u062a",
+               "\u0627\u06ab\u0633\u062a",
                "\u0633\u06d0\u067e\u062a\u0645\u0628\u0631",
                "\u0627\u06a9\u062a\u0648\u0628\u0631",
                "\u0646\u0648\u0645\u0628\u0631",
@@ -109,12 +109,27 @@ public class FormatData_ps extends ListResourceBundle {
                "\u062c\u0645\u0639\u0647",
                "\u0627\u0648\u0646\u06cd",
             };
+        final String[] metaValue_DayNarrows = new String[] {
+               "S",
+               "M",
+               "T",
+               "W",
+               "T",
+               "F",
+               "S",
+            };
         final String[] metaValue_QuarterNames = new String[] {
                "\u0644\u0648\u0645\u0693\u06cd \u0631\u0628\u0639\u0647",
                "\u06f2\u0645\u0647 \u0631\u0628\u0639\u0647",
                "\u06f3\u0645\u0647 \u0631\u0628\u0639\u0647",
                "\u06f4\u0645\u0647 \u0631\u0628\u0639\u0647",
             };
+        final String[] metaValue_QuarterNarrows = new String[] {
+               "1",
+               "2",
+               "3",
+               "4",
+            };
         final String[] metaValue_AmPmMarkers = new String[] {
                "\u063a.\u0645.",
                "\u063a.\u0648.",
@@ -125,21 +140,6 @@ public class FormatData_ps extends ListResourceBundle {
                "H:mm:ss",
                "H:mm",
             };
-        final String[] metaValue_buddhist_DayNarrows = new String[] {
-               "S",
-               "M",
-               "T",
-               "W",
-               "T",
-               "F",
-               "S",
-            };
-        final String[] metaValue_buddhist_QuarterNarrows = new String[] {
-               "1",
-               "2",
-               "3",
-               "4",
-            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE \u062f G y \u062f MMMM d",
                "\u062f G y \u062f MMMM d",
@@ -181,12 +181,12 @@ public class FormatData_ps extends ListResourceBundle {
             { "standalone.QuarterAbbreviations", metaValue_QuarterNames },
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
-            { "calendarname.islamic-civil", "\u062f \u0627\u0633\u0644\u0627\u0645\u064a \u062c\u0646\u062a\u0631\u064a (\u062c\u062f\u0648\u0644\u064a\u060c \u062f \u0645\u062f\u0646\u064a \u0639\u0635\u0631)" },
+            { "calendarname.islamic-civil", "\u0627\u0633\u0644\u0627\u0645\u064a \u062c\u0646\u062a\u0631\u064a (\u062c\u062f\u0648\u0644\u064a\u060c \u0645\u062f\u0646\u064a \u0639\u0635\u0631)" },
             { "islamic.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras",
                 new String[] {
-                    "BCE",
+                    "",
                     "\u0645.",
                 }
             },
@@ -194,7 +194,7 @@ public class FormatData_ps extends ListResourceBundle {
             { "timezone.regionFormat.standard", "{0} \u0645\u0639\u06cc\u0627\u0631\u06cc \u0648\u062e\u062a" },
             { "DefaultNumberingSystem", "arabext" },
             { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "calendarname.japanese", "\u062f \u062c\u0627\u067e\u0627\u0646\u064a \u062c\u0646\u062a\u0631\u064a" },
+            { "calendarname.japanese", "\u062c\u0627\u067e\u0627\u0646\u064a \u062c\u0646\u062a\u0631\u064a" },
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayNames },
             { "roc.MonthAbbreviations", metaValue_MonthNames },
@@ -205,6 +205,7 @@ public class FormatData_ps extends ListResourceBundle {
                     "\u0644\u0647 \u0645\u06cc\u0644\u0627\u062f \u0685\u062e\u0647 \u0648\u0631\u0648\u0633\u062a\u0647",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthNames },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -242,34 +243,54 @@ public class FormatData_ps extends ListResourceBundle {
             { "islamic.MonthNames",
                 new String[] {
                     "\u0645\u062d\u0631\u0645",
-                    "\u062f \u0635\u0641\u0631\u06d0 \u062f",
+                    "\u0635\u0641\u0631",
                     "\u0631\u0628\u064a\u0639",
                     "\u0631\u0628\u064a\u0639 II",
                     "\u062c\u0645\u0627\u0639\u0647",
                     "\u062c\u0645\u0648\u0645\u0627 II",
-                    "\u0631\u0627\u062c\u0627\u0628",
+                    "\u0631\u062c\u0628",
                     "\u0634\u0639\u0628\u0627\u0646",
                     "\u0631\u0645\u0636\u0627\u0646",
                     "\u0634\u0648\u0627\u0644",
-                    "\u062f\u0627\u0644\u0642\u0627\u0639\u062f\u0647",
-                    "\u062d\u0644\u0627\u0644 \u062d\u062c",
+                    "\u0630\u064a \u0627\u0644\u0642\u0639\u062f\u0647",
+                    "\u0630\u064a \u0627\u0644\u062d\u062c",
                     "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
             { "calendarname.roc", "\u0645\u0646\u06af\u0648\u0648 \u062c\u0646\u062a\u0631\u064a" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterNames },
             { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "field.month", "\u0645\u064a\u0627\u0634\u062a" },
-            { "field.second", "\u062b\u0627\u0646\u064a\u0647" },
-            { "DayAbbreviations", metaValue_DayNames },
-            { "NumberPatterns",
+            { "arabext.NumberPatterns",
                 new String[] {
                     "#,##0.###",
                     "#,##0.00\u00a0\u00a4",
                     "#,##0%",
+                    "",
                 }
             },
+            { "field.second", "\u062b\u0627\u0646\u064a\u0647" },
+            { "islamic.MonthNarrows",
+                new String[] {
+                    "1",
+                    "2",
+                    "3",
+                    "4",
+                    "5",
+                    "6",
+                    "7",
+                    "8",
+                    "9",
+                    "10",
+                    "11",
+                    "12",
+                    "",
+                }
+            },
+            { "DayAbbreviations", metaValue_DayNames },
+            { "DayNarrows", metaValue_DayNarrows },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0627\u0633\u0644\u0627\u0645\u064a \u062c\u0646\u062a\u0631\u064a" },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -283,7 +304,7 @@ public class FormatData_ps extends ListResourceBundle {
                     "\u0645\u06cd",
                     "\u062c\u0648\u0646",
                     "\u062c\u0648\u0644\u0627\u06cc",
-                    "\u0627\u06af\u0633\u062a",
+                    "\u0627\u06ab\u0633\u062a",
                     "\u0633\u067e\u062a\u0645\u0628\u0631",
                     "\u0627\u06a9\u062a\u0648\u0628\u0631",
                     "\u0646\u0648\u0645\u0628\u0631",
@@ -297,29 +318,29 @@ public class FormatData_ps extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0K",
-                    "00K",
-                    "000K",
-                    "0M",
-                    "00M",
-                    "000M",
-                    "0G",
-                    "00G",
-                    "000G",
-                    "0T",
-                    "00T",
-                    "000T",
+                    "{one:0K other:0K}",
+                    "{one:00K other:00K}",
+                    "{one:000K other:000K}",
+                    "{one:0M other:0M}",
+                    "{one:00M other:00M}",
+                    "{one:000M other:000M}",
+                    "{one:0G other:0G}",
+                    "{one:00G other:00G}",
+                    "{one:000G other:000G}",
+                    "{one:0T other:0T}",
+                    "{one:00T other:00T}",
+                    "{one:000T other:000T}",
                 }
             },
+            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.QuarterAbbreviations", metaValue_QuarterNames },
             { "roc.DayAbbreviations", metaValue_DayNames },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
             { "TimePatterns", metaValue_TimePatterns },
-            { "islamic.DayNarrows", metaValue_buddhist_DayNarrows },
+            { "islamic.DayNarrows", metaValue_DayNarrows },
             { "field.zone", "\u0648\u062e\u062a \u0633\u064a\u0645\u0647" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterNames },
             { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
@@ -332,6 +353,7 @@ public class FormatData_ps extends ListResourceBundle {
             },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
+            { "QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "field.weekday", "\u062f \u0627\u0648\u0646\u06cd \u0648\u0631\u0681" },
@@ -349,7 +371,8 @@ public class FormatData_ps extends ListResourceBundle {
             { "field.week", "\u0627\u0648\u0646\u06cd" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
+            { "roc.DayNarrows", metaValue_DayNarrows },
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
@@ -358,18 +381,18 @@ public class FormatData_ps extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0K",
-                    "00K",
-                    "000K",
-                    "0M",
-                    "00M",
-                    "000M",
-                    "0B",
-                    "00B",
-                    "000G",
-                    "0T",
-                    "00T",
-                    "000T",
+                    "{one:0K other:0K}",
+                    "{one:00K other:00K}",
+                    "{one:000K other:000K}",
+                    "{one:0M other:0M}",
+                    "{one:00M other:00M}",
+                    "{one:000M other:000M}",
+                    "{one:0B other:0B}",
+                    "{one:00B other:00B}",
+                    "{one:000G other:000B}",
+                    "{one:0T other:0T}",
+                    "{one:00T other:00T}",
+                    "{one:000T other:000T}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -390,17 +413,17 @@ public class FormatData_ps extends ListResourceBundle {
             { "islamic.MonthAbbreviations",
                 new String[] {
                     "\u0645\u062d\u0631\u0645",
-                    "\u0635\u0641\u0631\u0647",
+                    "\u0635\u0641\u0631",
                     "\u0631\u0628\u064a\u0639",
                     "\u0631\u0628\u064a\u0639 II",
-                    "\u062c\u0645\u0627\u0639\u0647",
-                    "\u062c\u0645\u0648\u0645\u0627 II",
-                    "\u0631\u0627\u062c\u0627\u0628",
+                    "\u062c\u0645\u0627\u062f \u06f1",
+                    "\u062c\u0645\u0627\u062f \u06f2",
+                    "\u0631\u062c\u0628",
                     "\u0634\u0639\u0628\u0627\u0646",
                     "\u0631\u0645\u0636\u0627\u0646",
                     "\u0634\u0648\u0627\u0644",
                     "\u062f\u0627\u0644\u0642\u0627\u0639\u062f\u0647",
-                    "\u062d\u0644\u0627\u0644 \u062d\u062c",
+                    "\u0630\u064a \u0627\u0644\u062d\u062c",
                     "",
                 }
             },
@@ -415,7 +438,7 @@ public class FormatData_ps extends ListResourceBundle {
                     "\u0645\u06cd",
                     "\u062c\u0648\u0646",
                     "\u062c\u0648\u0644\u0627\u06cc",
-                    "\u0627\u06af\u0633\u062a",
+                    "\u0627\u06ab\u0633\u062a",
                     "\u0633\u067e\u062a\u0645\u0628\u0631",
                     "\u0627\u06a9\u062a\u0648\u0628\u0631",
                     "\u0646\u0648\u0645\u0628\u0631",
@@ -423,11 +446,19 @@ public class FormatData_ps extends ListResourceBundle {
                     "",
                 }
             },
-            { "buddhist.DayNarrows", metaValue_buddhist_DayNarrows },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "\u00a4#,##0.00;(\u00a4#,##0.00)",
+                }
+            },
+            { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
-            { "japanese.DayNarrows", metaValue_buddhist_DayNarrows },
             { "QuarterAbbreviations", metaValue_QuarterNames },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
