@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -154,6 +154,12 @@ public class FormatData_sq extends ListResourceBundle {
                "tremujori III",
                "tremujori IV",
             };
+        final String[] metaValue_QuarterNarrows = new String[] {
+               "1",
+               "2",
+               "3",
+               "4",
+            };
         final String[] metaValue_AmPmMarkers = new String[] {
                "e paradites",
                "e pasdites",
@@ -172,12 +178,6 @@ public class FormatData_sq extends ListResourceBundle {
                "h:mm:ss a",
                "h:mm a",
             };
-        final String[] metaValue_buddhist_QuarterNarrows = new String[] {
-               "1",
-               "2",
-               "3",
-               "4",
-            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE, d MMM y G",
                "d MMM y G",
@@ -235,6 +235,7 @@ public class FormatData_sq extends ListResourceBundle {
                     "mbas Krishtit",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -270,6 +271,7 @@ public class FormatData_sq extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "paradite/pasdite" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
             { "calendarname.roc", "kalendar minguo (i Republik\u00ebs s\u00eb Kin\u00ebs)" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -277,13 +279,6 @@ public class FormatData_sq extends ListResourceBundle {
             { "field.second", "sekond\u00eb" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "kalendar islamik" },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -295,22 +290,22 @@ public class FormatData_sq extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 mij\u00eb",
-                    "00 mij\u00eb",
-                    "000 mij\u00eb",
-                    "0 milion",
-                    "00 milion",
-                    "000 milion",
-                    "0 miliard",
-                    "00 miliard",
-                    "000 miliard",
-                    "0 bilion",
-                    "00 bilion",
-                    "000 bilion",
+                    "{one:0' 'mij\u00eb other:0' 'mij\u00eb}",
+                    "{one:00' 'mij\u00eb other:00' 'mij\u00eb}",
+                    "{one:000' 'mij\u00eb other:000' 'mij\u00eb}",
+                    "{one:0' 'milion other:0' 'milion}",
+                    "{one:00' 'milion other:00' 'milion}",
+                    "{one:000' 'milion other:000' 'milion}",
+                    "{one:0' 'miliard other:0' 'miliard}",
+                    "{one:00' 'miliard other:00' 'miliard}",
+                    "{one:000' 'miliard other:000' 'miliard}",
+                    "{one:0' 'bilion other:0' 'bilion}",
+                    "{one:00' 'bilion other:00' 'bilion}",
+                    "{one:000' 'bilion other:000' 'bilion}",
                 }
             },
+            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames",
                 new String[] {
                     "Tremujori i 1-r\u00eb",
@@ -333,6 +328,7 @@ public class FormatData_sq extends ListResourceBundle {
             { "Eras", metaValue_Eras },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
+            { "QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "field.weekday", "dit\u00eb e jav\u00ebs" },
@@ -348,7 +344,7 @@ public class FormatData_sq extends ListResourceBundle {
             { "field.week", "jav\u00eb" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
@@ -358,18 +354,18 @@ public class FormatData_sq extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0mij\u00eb",
-                    "00\u00a0mij\u00eb",
-                    "000\u00a0mij\u00eb",
-                    "0\u00a0mln",
-                    "00\u00a0mln",
-                    "000\u00a0mln",
-                    "0\u00a0mld",
-                    "00\u00a0mld",
-                    "000\u00a0mld",
-                    "0\u00a0bln",
-                    "00\u00a0bln",
-                    "000\u00a0bln",
+                    "{one:0\u00a0mij\u00eb other:0\u00a0mij\u00eb}",
+                    "{one:00\u00a0mij\u00eb other:00\u00a0mij\u00eb}",
+                    "{one:000\u00a0mij\u00eb other:000\u00a0mij\u00eb}",
+                    "{one:0\u00a0mln other:0\u00a0mln}",
+                    "{one:00\u00a0mln other:00\u00a0mln}",
+                    "{one:000\u00a0mln other:000\u00a0mln}",
+                    "{one:0\u00a0mld other:0\u00a0mld}",
+                    "{one:00\u00a0mld other:00\u00a0mld}",
+                    "{one:000\u00a0mld other:000\u00a0mld}",
+                    "{one:0\u00a0bln other:0\u00a0bln}",
+                    "{one:00\u00a0bln other:00\u00a0bln}",
+                    "{one:000\u00a0bln other:000\u00a0bln}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -389,6 +385,14 @@ public class FormatData_sq extends ListResourceBundle {
             { "field.hour", "or\u00eb" },
             { "calendarname.buddhist", "kalendar budist" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "#,##0.00\u00a0\u00a4;(#,##0.00\u00a0\u00a4)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
