@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -172,6 +172,16 @@ public class FormatData_tr extends ListResourceBundle {
                "M\u00d6",
                "MS",
             };
+        final String[] metaValue_TimePatterns = new String[] {
+               "HH:mm:ss zzzz",
+               "HH:mm:ss z",
+               "HH:mm:ss",
+               "HH:mm",
+            };
+        final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
+               "BC",
+               "BE",
+            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "G d MMMM y EEEE",
                "G d MMMM y",
@@ -202,6 +212,7 @@ public class FormatData_tr extends ListResourceBundle {
             { "field.year", "y\u0131l" },
             { "calendarname.islamic-umalqura", "Hicri Takvim (\u00dcmm\u00fc-l Kurra Takvimi)" },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns",
                 new String[] {
@@ -216,6 +227,7 @@ public class FormatData_tr extends ListResourceBundle {
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "Arap Takvimi" },
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
             { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
@@ -300,20 +312,31 @@ public class FormatData_tr extends ListResourceBundle {
             { "field.month", "ay" },
             { "roc.Eras", metaValue_java_time_roc_Eras },
             { "field.second", "saniye" },
-            { "DayAbbreviations", metaValue_DayAbbreviations },
-            { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
+            { "islamic.MonthNarrows",
                 new String[] {
-                    "#,##0.###",
-                    "\u00a4#,##0.00",
-                    "%#,##0",
+                    "1",
+                    "2",
+                    "3",
+                    "4",
+                    "5",
+                    "6",
+                    "7",
+                    "8",
+                    "9",
+                    "10",
+                    "11",
+                    "12",
+                    "",
                 }
             },
+            { "DayAbbreviations", metaValue_DayAbbreviations },
+            { "DayNarrows", metaValue_DayNarrows },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "Hicri Takvim" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "{0} Saati" },
             { "long.CompactNumberPatterns",
@@ -321,18 +344,18 @@ public class FormatData_tr extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 bin",
-                    "00 bin",
-                    "000 bin",
-                    "0 milyon",
-                    "00 milyon",
-                    "000 milyon",
-                    "0 milyar",
-                    "00 milyar",
-                    "000 milyar",
-                    "0 trilyon",
-                    "00 trilyon",
-                    "000 trilyon",
+                    "{one:0' 'bin other:0' 'bin}",
+                    "{one:00' 'bin other:00' 'bin}",
+                    "{one:000' 'bin other:000' 'bin}",
+                    "{one:0' 'milyon other:0' 'milyon}",
+                    "{one:00' 'milyon other:00' 'milyon}",
+                    "{one:000' 'milyon other:000' 'milyon}",
+                    "{one:0' 'milyar other:0' 'milyar}",
+                    "{one:00' 'milyar other:00' 'milyar}",
+                    "{one:000' 'milyar other:000' 'milyar}",
+                    "{one:0' 'trilyon other:0' 'trilyon}",
+                    "{one:00' 'trilyon other:00' 'trilyon}",
+                    "{one:000' 'trilyon other:000' 'trilyon}",
                 }
             },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
@@ -342,7 +365,10 @@ public class FormatData_tr extends ListResourceBundle {
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
+            { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
+            { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "java.time.roc.Eras", metaValue_java_time_roc_Eras },
             { "field.zone", "saat dilimi" },
@@ -364,11 +390,13 @@ public class FormatData_tr extends ListResourceBundle {
             { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "java.time.buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
+            { "buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "field.week", "hafta" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
@@ -382,21 +410,22 @@ public class FormatData_tr extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0B",
-                    "00\u00a0B",
-                    "000\u00a0B",
-                    "0\u00a0Mn",
-                    "00\u00a0Mn",
-                    "000\u00a0Mn",
-                    "0\u00a0Mr",
-                    "00\u00a0Mr",
-                    "000\u00a0Mr",
-                    "0\u00a0Tn",
-                    "00\u00a0Tn",
-                    "000\u00a0Tn",
+                    "{one:0\u00a0B other:0\u00a0B}",
+                    "{one:00\u00a0B other:00\u00a0B}",
+                    "{one:000\u00a0B other:000\u00a0B}",
+                    "{one:0\u00a0Mn other:0\u00a0Mn}",
+                    "{one:00\u00a0Mn other:00\u00a0Mn}",
+                    "{one:000\u00a0Mn other:000\u00a0Mn}",
+                    "{one:0\u00a0Mr other:0\u00a0Mr}",
+                    "{one:00\u00a0Mr other:00\u00a0Mr}",
+                    "{one:000\u00a0Mr other:000\u00a0Mr}",
+                    "{one:0\u00a0Tn other:0\u00a0Tn}",
+                    "{one:00\u00a0Tn other:00\u00a0Tn}",
+                    "{one:000\u00a0Tn other:000\u00a0Tn}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "java.time.buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "timezone.regionFormat.daylight", "{0} Yaz Saati" },
             { "DatePatterns",
                 new String[] {
@@ -407,6 +436,7 @@ public class FormatData_tr extends ListResourceBundle {
                 }
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.TimePatterns", metaValue_TimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "saat" },
@@ -430,10 +460,19 @@ public class FormatData_tr extends ListResourceBundle {
             { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "Budist Takvimi" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4#,##0.00",
+                    "%#,##0",
+                    "\u00a4#,##0.00;(\u00a4#,##0.00)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
+            { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
