@@ -303,6 +303,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "Inds", "Indus" },
             { "ady", "Adyghe" },
             { "type.k0.600dpi", "600 dpi Keyboard" },
+            { "cic", "Chickasaw" },
             { "aeb", "Tunisian Arabic" },
             { "FI", "Finland" },
             { "FJ", "Fiji" },
@@ -676,6 +677,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "TC", "Turks & Caicos Islands" },
             { "yav", "Yangben" },
             { "TD", "Chad" },
+            { "Qaag", "Zawgyi" },
             { "TF", "French Southern Territories" },
             { "ase", "American Sign Language" },
             { "TG", "Togo" },
@@ -1522,7 +1524,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "mul", "Multiple languages" },
             { "cad", "Caddo" },
             { "key.ms", "Measurement System" },
-            { "mus", "Creek" },
+            { "mus", "Muscogee" },
             { "Glag", "Glagolitic" },
             { "gil", "Gilbertese" },
             { "%%KKCOR", "Common Orthography" },
