@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -72,51 +72,144 @@ public class CurrencyNames_da extends OpenListResourceBundle {
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
             { "AED", "AED" },
+            { "AFN", "AFN" },
+            { "ALL", "ALL" },
             { "AMD", "AMD" },
+            { "ANG", "ANG" },
+            { "AOA", "AOA" },
+            { "ARS", "ARS" },
             { "AUD", "AU$" },
+            { "AWG", "AWG" },
             { "AZN", "AZN" },
+            { "BAM", "BAM" },
+            { "BBD", "BBD" },
+            { "BDT", "BDT" },
+            { "BGN", "BGN" },
             { "BHD", "BHD" },
             { "BIF", "BIF" },
+            { "BMD", "BMD" },
+            { "BND", "BND" },
+            { "BOB", "BOB" },
+            { "BSD", "BSD" },
+            { "BTN", "BTN" },
             { "BWP", "BWP" },
+            { "BYN", "BYN" },
+            { "BYR", "BYR" },
+            { "BZD", "BZD" },
+            { "CDF", "CDF" },
+            { "CHF", "CHF" },
+            { "CLP", "CLP" },
             { "CNH", "CNH" },
+            { "COP", "COP" },
+            { "CRC", "CRC" },
+            { "CUC", "CUC" },
+            { "CUP", "CUP" },
+            { "CVE", "CVE" },
+            { "CZK", "CZK" },
             { "DJF", "DJF" },
             { "DKK", "kr." },
+            { "DOP", "DOP" },
+            { "DZD", "DZD" },
+            { "EGP", "EGP" },
             { "ERN", "ERN" },
             { "ETB", "ETB" },
             { "FJD", "FJD" },
+            { "FKP", "FKP" },
             { "GEL", "GEL" },
+            { "GHS", "GHS" },
+            { "GIP", "GIP" },
+            { "GMD", "GMD" },
+            { "GNF", "GNF" },
+            { "GTQ", "GTQ" },
+            { "GYD", "GYD" },
+            { "HNL", "HNL" },
+            { "HRK", "HRK" },
+            { "HTG", "HTG" },
+            { "HUF", "HUF" },
+            { "IDR", "IDR" },
             { "IQD", "IQD" },
+            { "IRR", "IRR" },
+            { "ISK", "ISK" },
+            { "JMD", "JMD" },
             { "JOD", "JOD" },
             { "KES", "KES" },
             { "KGS", "KGS" },
+            { "KHR", "KHR" },
             { "KMF", "KMF" },
+            { "KPW", "KPW" },
             { "KWD", "KWD" },
+            { "KYD", "KYD" },
             { "KZT", "KZT" },
+            { "LAK", "LAK" },
             { "LBP", "LBP" },
+            { "LKR", "LKR" },
+            { "LRD", "LRD" },
+            { "LTL", "LTL" },
+            { "LVL", "LVL" },
+            { "LYD", "LYD" },
+            { "MAD", "MAD" },
+            { "MDL", "MDL" },
             { "MGA", "MGA" },
+            { "MKD", "MKD" },
+            { "MMK", "MMK" },
+            { "MNT", "MNT" },
+            { "MOP", "MOP" },
+            { "MRO", "MRO" },
+            { "MRU", "MRU" },
             { "MUR", "MUR" },
+            { "MVR", "MVR" },
             { "MWK", "MWK" },
+            { "MYR", "MYR" },
             { "MZN", "MZN" },
             { "NAD", "NAD" },
+            { "NGN", "NGN" },
+            { "NIO", "NIO" },
+            { "NOK", "NOK" },
+            { "NPR", "NPR" },
             { "OMR", "OMR" },
+            { "PAB", "PAB" },
+            { "PEN", "PEN" },
             { "PGK", "PGK" },
+            { "PHP", "PHP" },
+            { "PKR", "PKR" },
+            { "PLN", "PLN" },
+            { "PYG", "PYG" },
             { "QAR", "QAR" },
+            { "RON", "RON" },
+            { "RSD", "RSD" },
+            { "RUB", "RUB" },
             { "RWF", "RWF" },
             { "SAR", "SAR" },
             { "SBD", "SBD" },
             { "SCR", "SCR" },
+            { "SDG", "SDG" },
+            { "SEK", "SEK" },
+            { "SGD", "SGD" },
+            { "SHP", "SHP" },
+            { "SLL", "SLL" },
             { "SOS", "SOS" },
+            { "SRD", "SRD" },
+            { "SSP", "SSP" },
+            { "STD", "STD" },
+            { "STN", "STN" },
             { "SYP", "SYP" },
             { "SZL", "SZL" },
             { "THB", "\u0e3f" },
             { "TJS", "TJS" },
             { "TMT", "TMT" },
+            { "TND", "TND" },
+            { "TOP", "TOP" },
             { "TRY", "TRY" },
+            { "TTD", "TTD" },
             { "TZS", "TZS" },
+            { "UAH", "UAH" },
             { "UGX", "UGX" },
-            { "USD", "$" },
+            { "UYU", "UYU" },
             { "UZS", "UZS" },
+            { "VEF", "VEF" },
             { "VES", "VES" },
+            { "VUV", "VUV" },
+            { "WST", "WST" },
             { "YER", "YER" },
             { "ZAR", "ZAR" },
             { "ZMK", "ZMK" },
@@ -221,7 +314,7 @@ public class CurrencyNames_da extends OpenListResourceBundle {
             { "gwe", "Portugisisk guinea escudo" },
             { "gwp", "Guineansk peso" },
             { "gyd", "guyansk dollar" },
-            { "hkd", "Hongkong dollar" },
+            { "hkd", "hongkongsk dollar" },
             { "hnl", "honduransk lempira" },
             { "hrd", "Kroatisk dinar" },
             { "hrk", "kroatisk kuna" },
