@@ -70,169 +70,306 @@ import sun.util.resources.OpenListResourceBundle;
 public class CurrencyNames_sd extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
+        final String metaValue_BYR = "BYR";
         final Object[][] data = new Object[][] {
-            { "PKR", "Rs" },
-            { "VES", "VES" },
-            { "aed", "\u06af\u068f\u064a\u0644 \u0639\u0631\u0628 \u0627\u0645\u0627\u0631\u0627\u062a \u062f\u0631\u0647\u0645" },
-            { "afn", "\u0627\u0641\u063a\u0627\u0646\u064a \u0627\u0641\u063a\u0627\u0646\u064a" },
-            { "all", "\u0627\u0644\u0628\u0627\u0646\u064a \u0644\u064a\u06aa" },
-            { "amd", "\u0627\u0631\u0645\u0627\u0646\u064a \u068a\u0631\u0645" },
-            { "ang", "\u0646\u064a\u068c\u0631\u0644\u064a\u0646\u068a \u0627\u0646\u067d\u0644\u064a\u0626\u0646 \u06af\u0644\u068a\u0631" },
-            { "aoa", "\u0627\u0646\u06af\u0648\u0644\u064a\u0627\u0626\u064a \u06aa\u0648\u0627\u0646\u0632\u0627" },
-            { "ars", "\u0627\u0631\u062c\u0646\u067d\u0627\u0626\u0646 \u067e\u064a\u0633\u0648" },
-            { "aud", "\u0622\u0633\u067d\u0631\u064a\u0644\u0648\u064a \u068a\u0627\u0644\u0631" },
-            { "awg", "\u0627\u0631\u0648\u0628\u0646 \u0641\u0644\u0648\u0631\u0646" },
-            { "azn", "\u0622\u0630\u0631\u0628\u0627\u0626\u064a\u062c\u0627\u0646\u064a \u0645\u0646\u062a" },
-            { "bam", "\u0628\u0648\u0633\u0646\u064a\u0627 \u0647\u0631\u0632\u06af\u0648\u064a\u0646\u0627 \u06aa\u0646\u0648\u0631\u067d\u0628\u0644 \u0645\u0627\u0631\u06aa" },
-            { "bbd", "\u0628\u0627\u0631\u0628\u064a\u068a\u064a\u0646 \u068a\u0627\u0644\u0631" },
-            { "bdt", "\u0628\u0646\u06af\u0644\u0627\u062f\u064a\u0634\u064a \u067d\u06aa\u0627" },
-            { "bgn", "\u0628\u0644\u063a\u0627\u0631\u06cc\u0646 \u0644\u06cc\u0648" },
-            { "bhd", "\u0628\u062d\u0631\u064a\u0646\u064a \u062f\u064a\u0646\u0627\u0631" },
-            { "bif", "\u0628\u0631\u0648\u0646\u068a\u064a \u0641\u0631\u064a\u0646\u06aa" },
-            { "bmd", "\u0628\u0631\u0645\u0648\u062f\u064a \u068a\u0627\u0644\u0631" },
-            { "bnd", "\u0628\u0631\u0648\u0646\u0627\u0626\u064a \u068a\u0627\u0644\u0631" },
-            { "bob", "\u0628\u0648\u0644\u06cc\u0648\u06cc\u0646 \u0628\u0648\u0644\u06cc\u0648\u06cc\u0627\u0646\u0648" },
-            { "brl", "\u0628\u0631\u0627\u0632\u064a\u0644\u064a \u0631\u064a\u0644" },
-            { "bsd", "\u0628\u0647\u0627\u0645\u0627\u0646\u064a \u068a\u0627\u062f\u0644\u0631" },
-            { "btn", "\u0680\u0648\u067d\u0627\u0646\u064a \u06af\u0644\u067d\u0631\u0645" },
-            { "bwp", "\u0628\u0648\u0633\u062a\u0648\u0627\u0646\u064a \u067e\u0648\u0644\u0627" },
-            { "byn", "\u0628\u06cc\u0644\u0627\u0631\u0648\u0633\u06cc \u0631\u0628\u0644" },
-            { "byr", "BYR" },
-            { "bzd", "\u0628\u064a\u0644\u064a\u0632 \u068a\u0627\u0644\u0631" },
-            { "cad", "\u06aa\u0626\u064a\u0646\u068a\u064a\u0627\u0626\u064a \u068a\u0627\u0644\u0631" },
-            { "cdf", "\u06aa\u0627\u0646\u06af\u0648 \u0641\u0631\u064a\u0646\u06aa" },
-            { "chf", "\u0633\u0648\u0626\u0633 \u0641\u0631\u064a\u0646\u06aa" },
-            { "clp", "\u0686\u0644\u064a \u067e\u064a\u0633\u0648" },
-            { "cnh", "\u0686\u064a\u0646\u064a \u064a\u0648\u0622\u0646 (\u063a\u064a\u0631 \u0645\u0644\u06aa\u064a)" },
-            { "cny", "\u0686\u064a\u0646\u064a \u064a\u0648\u0622\u0646" },
-            { "cop", "\u06aa\u0648\u0644\u0645\u0628\u064a\u0627\u0626\u064a \u067e\u064a\u0633\u0648" },
-            { "crc", "\u06aa\u0648\u0633\u067d\u0627 \u0631\u064a\u06aa\u0627 \u06aa\u0648\u0644\u0646" },
-            { "cuc", "\u06aa\u064a\u0648\u0628\u0646 \u06aa\u0646\u0648\u0631\u067d\u064a\u0628\u0644 \u067e\u064a\u0633\u0648" },
-            { "cup", "\u06aa\u064a\u0648\u0628\u0646 \u067e\u064a\u0633\u0648" },
-            { "cve", "\u06aa\u064a\u067e \u0648\u0631\u062f\u064a \u0627\u064a\u0633\u06aa\u0648\u068a\u0648" },
-            { "czk", "\u0686\u064a\u06aa \u06aa\u0631\u0648\u0646\u0627" },
-            { "djf", "\u062c\u0628\u0648\u062a\u064a \u0641\u0631\u064a\u0646\u06aa" },
-            { "dkk", "\u062f\u0627\u0646\u0634 \u06aa\u0631\u0648\u0646" },
-            { "dop", "\u068a\u0648\u0645\u064a\u0646\u064a\u06aa\u0646 \u067e\u064a\u0633\u0648" },
-            { "dzd", "\u0627\u0644\u062c\u064a\u0631\u064a\u0627\u0626\u064a \u062f\u064a\u0646\u0627\u0631" },
-            { "egp", "\u0645\u0635\u0631\u064a \u067e\u0627\u0626\u0648\u0646\u068a" },
-            { "ern", "\u0627\u064a\u0631\u064a\u067d\u064a\u0631\u064a\u0627\u0626\u064a \u0646\u0627\u06aa\u0641\u0627" },
-            { "etb", "\u0627\u064a\u067f\u0648\u067e\u064a\u0627\u0626\u064a \u0628\u0631" },
-            { "eur", "\u064a\u0648\u0631\u0648" },
-            { "fjd", "\u0641\u062c\u064a \u068a\u0627\u0644\u0631" },
-            { "fkp", "\u0641\u0627\u06aa\u0644\u064a\u0646\u068a \u067b\u064a\u067d \u067e\u0627\u0626\u0648\u0646\u068a" },
-            { "gbp", "\u0628\u0631\u0637\u0627\u0646\u0648\u064a \u067e\u0627\u0626\u0648\u0646\u068a" },
-            { "gel", "\u062c\u0627\u0631\u062c\u064a\u0627\u0626\u064a \u0644\u0627\u0631\u064a" },
-            { "ghs", "\u06af\u0647\u0627\u0646\u064a\u0646 \u0633\u064a\u062f\u064a" },
-            { "gip", "\u062c\u0628\u0631\u0627\u0644\u067d\u0631 \u067e\u0627\u0626\u0648\u0646\u068a" },
-            { "gmd", "\u06af\u064a\u0645\u0628\u064a\u0627 \u062f\u0644\u0627\u0633\u0627\u0626\u064a" },
-            { "gnf", "\u06af\u0646\u064a \u0641\u0631\u064a\u0646\u06aa" },
-            { "gtq", "\u06af\u0648\u0626\u067d\u064a \u0645\u0627\u0644\u0627 \u06aa\u067d\u0632\u0644" },
-            { "gyd", "\u06af\u064a\u0627\u0646\u0627 \u068a\u0627\u0644\u0631" },
-            { "hkd", "\u0647\u0627\u0646\u06af \u06aa\u0627\u0646\u06af \u068a\u0627\u0644\u0631" },
-            { "hnl", "\u0647\u0648\u0646\u068a\u0648\u0631\u0627\u0633 \u0644\u064a\u0645\u067e\u0631\u0627" },
-            { "hrk", "\u06aa\u0631\u0648\u0634\u064a\u0627\u0626\u064a \u06aa\u0648\u0646\u0627" },
-            { "htg", "\u0647\u064a\u067d\u064a \u06af\u0648\u0631\u068a\u064a" },
-            { "huf", "\u0647\u0646\u06af\u064a\u0631\u064a\u0646 \u0641\u0648\u0631\u0646\u067d" },
-            { "idr", "\u0627\u0646\u068a\u0648\u0646\u064a\u0634\u064a\u0627\u0626\u064a \u0631\u067e\u064a\u0647" },
-            { "ils", "\u0627\u0633\u0631\u0627\u0626\u064a\u0644\u064a \u0646\u064a\u0648 \u0634\u064a\u06aa\u0644" },
-            { "inr", "\u0627\u0646\u068a\u064a\u0646 \u0631\u067e\u064a" },
-            { "iqd", "\u0639\u0631\u0627\u0642\u064a \u062f\u064a\u0646\u0627\u0631" },
-            { "irr", "\u0627\u064a\u0631\u0627\u0646\u064a \u0631\u064a\u0627\u0644" },
-            { "isk", "\u0622\u0626\u064a\u0633 \u0644\u064a\u0646\u068a\u064a \u06aa\u0631\u0648\u0646\u0627" },
-            { "jmd", "\u062c\u0645\u064a\u06aa\u0627\u0626\u064a \u068a\u0627\u0644\u0631" },
-            { "jod", "\u0627\u0631\u062f\u0646\u064a \u062f\u064a\u0646\u0627\u0631" },
-            { "jpy", "\u062c\u0627\u067e\u0627\u0646\u064a \u064a\u064a\u0646" },
-            { "kes", "\u06aa\u064a\u0646\u064a\u0627\u0626\u064a \u0633\u0644\u0646\u06af" },
-            { "kgs", "\u06aa\u0631\u063a\u0632\u0633\u062a\u0627\u0646\u064a \u0633\u0648\u0645" },
-            { "khr", "\u06aa\u0645\u0628\u0648\u068a\u064a\u0627\u0626\u064a \u0631\u064a\u0627\u0644" },
-            { "kmf", "\u06aa\u0648\u0645\u0648\u0631\u064a\u0627\u0626\u064a \u0641\u0631\u064a\u0646\u06aa" },
-            { "kpw", "\u0627\u062a\u0631 \u06aa\u0648\u0631\u064a\u0627\u0626\u064a \u0648\u0646" },
-            { "krw", "\u068f\u06a9\u06bb \u06aa\u0648\u0631\u064a\u0627\u0626\u064a \u0648\u0646" },
-            { "kwd", "\u06aa\u0648\u064a\u062a\u064a \u062f\u064a\u0646\u0627\u0631" },
-            { "kyd", "\u06aa\u064a\u0645\u064a\u0646 \u067b\u064a\u067d \u068a\u0627\u0644\u0631" },
-            { "kzt", "\u0642\u0627\u0632\u0642\u0633\u062a\u0627\u0646 \u067d\u064a\u0646\u06af\u0627" },
-            { "lak", "\u0644\u0627\u0626\u0648\u0634\u064a\u0627\u0626\u064a \u06aa\u067e" },
-            { "lbp", "\u0644\u0628\u0646\u0627\u0646\u064a \u067e\u0627\u0626\u0648\u0646\u068a" },
-            { "lkr", "\u0633\u0631\u064a \u0644\u0646\u06aa\u0646 \u0631\u067e\u064a" },
-            { "lrd", "\u0644\u0627\u0626\u0628\u06cc\u0631\u06cc\u0627\u0626\u06cc \u068a\u0627\u0644\u0631" },
-            { "lyd", "\u0644\u0628\u064a\u0627\u0626\u064a \u062f\u064a\u0646\u0627\u0631" },
-            { "mad", "\u0645\u0648\u0631\u0648\u06aa\u064a\u0627\u0626\u064a \u062f\u0631\u0647\u0645" },
-            { "mdl", "\u0645\u0627\u0644\u062f\u064a\u067e \u0644\u064a\u0648" },
-            { "mga", "\u0645\u0644\u0627\u06af\u0627\u0633\u064a \u0627\u0631\u06cc\u0627\u0631\u06cc" },
-            { "mkd", "\u0645\u064a\u0633\u064a \u068a\u0648\u0646\u064a \u062f\u064a\u0646\u0627\u0631" },
-            { "mmk", "\u0645\u064a\u0627\u0646\u0645\u0627\u0631 \u06aa\u064a\u0627\u067d" },
-            { "mnt", "\u0645\u0646\u06af\u0648\u0644\u064a \u062a\u062c\u0631\u06aa" },
-            { "mop", "\u0645\u064a\u06aa\u0627\u0646\u064a\u0632 \u067e\u067d\u0627\u06aa\u0627" },
-            { "mro", "\u0645\u0648\u0631\u064a\u0634\u064a\u0627\u0626\u064a \u0627\u0648\u06af\u0648\u0626\u06cc\u0627 (1973\u20132017)" },
-            { "mru", "\u0645\u0648\u0631\u064a\u0634\u064a\u0627\u0626\u064a \u0627\u0648\u06af\u0648\u0626\u06cc\u0627" },
-            { "mur", "\u0645\u0627\u0631\u064a\u0634\u064a\u0627\u0626\u064a \u0631\u067e\u064a" },
-            { "mvr", "\u0645\u0627\u0644\u062f\u064a\u067e \u0631\u0648\u0641\u064a\u0627" },
             { "mwk", "\u0645\u0644\u0627\u0648\u064a \u06aa\u0648\u0627\u0686\u0627" },
-            { "mxn", "\u0645\u064a\u06aa\u0633\u064a\u06aa\u0648 \u067e\u064a\u0633\u0648" },
-            { "myr", "\u0645\u0644\u0627\u0626\u064a\u0634\u064a\u0627\u0626\u064a \u0631\u0646\u06af\u067d" },
-            { "mzn", "\u0645\u0648\u0632\u0645\u0628\u064a\u0642 \u0645\u064a\u067d\u064a\u06aa\u0644" },
-            { "nad", "\u0646\u0645\u064a\u0628\u0627\u0626\u064a \u068a\u0627\u0644\u0631" },
-            { "ngn", "\u0646\u0627\u0626\u062c\u0631\u064a\u0627\u0626\u064a \u0646\u0627\u0626\u0631\u0627" },
-            { "nio", "\u0646\u06aa\u0627\u0631\u0627 \u06af\u0648\u0627 \u06aa\u0627\u0631\u068a\u0648\u0628\u0627" },
-            { "nok", "\u0646\u0627\u0631\u0648\u064a\u0627\u0626\u064a \u06aa\u0631\u0648\u0646" },
-            { "npr", "\u0646\u064a\u067e\u0627\u0644\u064a \u0631\u067e\u064a" },
-            { "nzd", "\u0646\u064a\u0648\u0632\u064a \u0644\u064a\u0646\u068a\u064a \u068a\u0627\u0644\u0631" },
-            { "omr", "\u0639\u0645\u0627\u0646\u064a \u0631\u064a\u0627\u0644" },
-            { "pab", "\u067e\u0627\u0646\u0627\u0645\u0627 \u067e\u0627\u0644\u0628\u0648\u0627" },
-            { "pen", "\u067e\u064a\u0631\u0648 \u0633\u0648\u0644" },
-            { "pgk", "\u067e\u0627\u067e\u0648\u0627 \u0646\u064a\u0648 \u06af\u0646\u064a \u06aa\u0646\u0627" },
-            { "php", "\u0641\u0644\u067e\u0627\u0626\u0646\u064a \u067e\u064a\u0633\u0648" },
-            { "pkr", "\u067e\u0627\u06aa\u0633\u062a\u0627\u0646\u064a \u0631\u067e\u064a" },
-            { "pln", "\u067e\u0648\u0644\u0634 \u0632\u0644\u0627\u067d\u064a" },
-            { "pyg", "\u067e\u064a\u0631\u0627\u06af\u0648\u0626\u064a \u06af\u0627\u0631\u0627\u0646\u064a" },
-            { "qar", "\u0642\u0637\u0631\u064a \u0631\u064a\u0627\u0644" },
-            { "ron", "\u0631\u0648\u0645\u0627\u0646\u06cc\u0627\u0626\u064a \u0644\u06cc\u0648" },
-            { "rsd", "\u0633\u0631\u0628\u064a\u0627 \u062f\u064a\u0646\u0627\u0631" },
-            { "rub", "\u0631\u0648\u0633\u064a \u0631\u0628\u0644" },
-            { "rwf", "\u0631\u0648\u0627\u0646\u068a\u0627 \u0641\u0631\u064a\u0646\u06aa" },
-            { "sar", "\u0633\u0639\u0648\u062f\u064a \u0631\u064a\u0627\u0644" },
-            { "sbd", "\u0633\u0648\u0644\u0648\u0645\u0627\u0646 \u067b\u064a\u067d \u068a\u0627\u0644\u0631" },
-            { "scr", "\u0633\u0634\u0644\u064a \u0631\u067e\u064a" },
-            { "sdg", "\u0633\u0648\u068a\u0627\u0646\u064a \u067e\u0627\u0626\u0648\u0646\u068a" },
-            { "sek", "\u0633\u0648\u064a\u068a\u0646\u064a \u06aa\u0631\u0648\u0646\u0627" },
-            { "sgd", "\u0633\u0646\u06af\u0627\u067e\u0648\u0631\u064a \u068a\u0627\u0644\u0631" },
-            { "shp", "\u0633\u064a\u0646\u067d \u0647\u064a\u0644\u0646\u0627 \u067e\u0627\u0626\u0648\u0646\u068a" },
-            { "sll", "\u0633\u06cc\u0631\u0627 \u0644\u06cc\u0648\u0646\u064a\u0627\u0626\u064a \u0644\u06cc\u0648\u0646" },
-            { "sos", "\u0633\u0648\u0645\u0627\u0644\u064a \u0634\u0644\u0646\u06af" },
-            { "srd", "\u0633\u0631\u064a\u0646\u0627\u0645\u064a \u068a\u0627\u0644\u0631" },
+            { "FJD", "FJD" },
+            { "STD", "STD" },
+            { "SCR", "SCR" },
+            { "CDF", "CDF" },
+            { "BBD", "BBD" },
+            { "mga", "\u0645\u0644\u0627\u06af\u0627\u0633\u064a \u0627\u0631\u06cc\u0627\u0631\u06cc" },
+            { "HNL", "HNL" },
+            { "UGX", "UGX" },
+            { "ZAR", "ZAR" },
+            { "STN", "STN" },
+            { "bam", "\u0628\u0648\u0633\u0646\u064a\u0627 \u0647\u0631\u0632\u06af\u0648\u064a\u0646\u0627 \u06aa\u0646\u0648\u0631\u067d\u0628\u0644 \u0645\u0627\u0631\u06aa" },
+            { "egp", "\u0645\u0635\u0631\u064a \u067e\u0627\u0626\u0648\u0646\u068a" },
+            { "CUC", "CUC" },
             { "ssp", "\u068f\u06a9\u06bb \u0633\u0648\u068a\u0627\u0646\u064a \u067e\u0627\u0626\u0648\u0646\u068a" },
+            { "BSD", "BSD" },
+            { "nio", "\u0646\u06aa\u0627\u0631\u0627 \u06af\u0648\u0627 \u06aa\u0627\u0631\u068a\u0648\u0628\u0627" },
+            { "SDG", "SDG" },
+            { "nzd", "\u0646\u064a\u0648\u0632\u064a \u0644\u064a\u0646\u068a\u064a \u068a\u0627\u0644\u0631" },
+            { "IQD", "IQD" },
+            { "brl", "\u0628\u0631\u0627\u0632\u064a\u0644\u064a \u0631\u064a\u0644" },
+            { "CUP", "CUP" },
+            { "GMD", "GMD" },
+            { "fjd", "\u0641\u062c\u064a \u068a\u0627\u0644\u0631" },
+            { "RSD", "RSD" },
+            { "mxn", "\u0645\u064a\u06aa\u0633\u064a\u06aa\u0648 \u067e\u064a\u0633\u0648" },
             { "std", "\u0633\u0627\u0626\u0648 \u067d\u0648\u0645 \u06fd \u067e\u0631\u0646\u0633\u067e\u064a \u062f\u0648\u0628\u0631\u0627 (1977\u20132017)" },
-            { "stn", "\u0633\u0627\u0626\u0648 \u067d\u0648\u0645 \u06fd \u067e\u0631\u0646\u0633\u067e\u064a \u062f\u0648\u0628\u0631\u0627" },
-            { "syp", "\u0633\u064a\u0631\u064a\u0627\u0626\u064a \u067e\u0627\u0626\u0648\u0646\u068a" },
-            { "szl", "\u0633\u0648\u0627\u0632\u064a \u0644\u0644\u0627\u0646\u06af\u064a\u0646\u064a" },
-            { "thb", "\u067f\u0627\u0626\u064a \u0628\u0627\u0647\u062a" },
-            { "tjs", "\u062a\u0627\u062c\u06aa\u0633\u062a\u0627\u0646\u064a \u0633\u0648\u0645\u0648\u0646\u064a" },
-            { "tmt", "\u062a\u0631\u06aa\u0645\u0627\u0646\u0633\u062a\u0627\u0646 \u0645\u0646\u062a" },
-            { "tnd", "\u062a\u06cc\u0648\u0646\u0633 \u062f\u06cc\u0646\u0627\u0631" },
-            { "top", "\u062a\u0648\u0646\u06af\u0646 \u067e\u0627\u0646\u06af\u0627" },
-            { "try", "\u062a\u0631\u06aa\u064a \u0644\u0631\u0627" },
-            { "ttd", "\u067d\u0631\u064a\u0646\u068a\u064a\u068a \u06fd \u067d\u0648\u0628\u0627\u06af\u0648 \u068a\u0627\u0644\u0631" },
-            { "twd", "\u0646\u064a\u0648 \u062a\u0627\u0626\u064a\u0648\u0627\u0646 \u068a\u0627\u0644\u0631" },
-            { "tzs", "\u062a\u0646\u0632\u0627\u0646\u064a\u0627\u0626\u064a \u0634\u0644\u0646\u06af" },
-            { "uah", "\u06cc\u0648\u06aa\u0631\u0627\u0626\u0646 \u0647\u0631\u06cc\u0648\u0646\u06cc\u0627" },
+            { "scr", "\u0633\u0634\u0644\u064a \u0631\u067e\u064a" },
+            { "cdf", "\u06aa\u0627\u0646\u06af\u0648 \u0641\u0631\u064a\u0646\u06aa" },
+            { "bbd", "\u0628\u0627\u0631\u0628\u064a\u068a\u064a\u0646 \u068a\u0627\u0644\u0631" },
+            { "MYR", "MYR" },
+            { "hnl", "\u0647\u0648\u0646\u068a\u0648\u0631\u0627\u0633 \u0644\u064a\u0645\u067e\u0631\u0627" },
             { "ugx", "\u064a\u06af\u0627\u0646\u068a\u0627 \u0634\u0644\u0646\u06af" },
-            { "usd", "\u0622\u0645\u0631\u064a\u06aa\u064a \u068a\u0627\u0644\u0631" },
-            { "uyu", "\u064a\u0648\u0631\u0648\u06af\u0648\u0626\u064a \u067e\u064a\u0633\u0648" },
-            { "uzs", "\u0627\u0632\u0628\u06aa\u0633\u062a\u0627\u0646\u064a \u0633\u0648\u0645" },
-            { "vef", "Venezuelan Bol\u00edvar (2008\u20132018)" },
-            { "ves", "\u0648\u06cc\u0646\u0632\u0648\u06cc\u0644\u0627 \u0628\u0648\u0644\u06cc\u0648\u0631" },
-            { "vnd", "\u0648\u064a\u067d\u0646\u0627\u0645\u064a \u068a\u0648\u0646\u06af" },
-            { "vuv", "\u0648\u0627\u0646\u0648\u0627\u062a\u0648 \u0648\u0627\u062a\u0648" },
-            { "wst", "\u0633\u0627\u0645\u0648\u0622\u0646 \u067d\u0627\u0644\u0627" },
-            { "xaf", "\u0648\u0686 \u0622\u0641\u0631\u064a\u06aa\u0627 \u0641\u0631\u064a\u0646\u06aa" },
-            { "xcd", "\u0627\u0648\u0680\u0631 \u06aa\u064a\u0631\u064a\u0628\u064a\u0646 \u068a\u0627\u0644\u0631" },
-            { "xof", "\u0627\u0648\u0644\u0647\u0647 \u0622\u0641\u0631\u064a\u06aa\u0627 \u0641\u0631\u064a\u0646\u06aa" },
-            { "xpf", "CFP \u0641\u0631\u064a\u0646\u06aa" },
-            { "xxx", "\u0627\u06bb\u0684\u0627\u062a\u0644 \u0633\u06aa\u0648" },
-            { "yer", "\u064a\u0645\u0646\u064a \u0631\u064a\u0627\u0644" },
+            { "FKP", "FKP" },
             { "zar", "\u068f\u06a9\u06bb \u0622\u0641\u0631\u064a\u0642\u064a \u0631\u0627\u0646\u068a" },
+            { "stn", "\u0633\u0627\u0626\u0648 \u067d\u0648\u0645 \u06fd \u067e\u0631\u0646\u0633\u067e\u064a \u062f\u0648\u0628\u0631\u0627" },
+            { "UYU", "UYU" },
+            { "cuc", "\u06aa\u064a\u0648\u0628\u0646 \u06aa\u0646\u0648\u0631\u067d\u064a\u0628\u0644 \u067e\u064a\u0633\u0648" },
+            { "bsd", "\u0628\u0647\u0627\u0645\u0627\u0646\u064a \u068a\u0627\u062f\u0644\u0631" },
+            { "CVE", "CVE" },
+            { "OMR", "OMR" },
+            { "sdg", "\u0633\u0648\u068a\u0627\u0646\u064a \u067e\u0627\u0626\u0648\u0646\u068a" },
+            { "KES", "KES" },
+            { "SEK", "SEK" },
+            { "BTN", "BTN" },
+            { "iqd", "\u0639\u0631\u0627\u0642\u064a \u062f\u064a\u0646\u0627\u0631" },
+            { "GNF", "GNF" },
+            { "cup", "\u06aa\u064a\u0648\u0628\u0646 \u067e\u064a\u0633\u0648" },
+            { "gmd", "\u06af\u064a\u0645\u0628\u064a\u0627 \u062f\u0644\u0627\u0633\u0627\u0626\u064a" },
+            { "MZN", "MZN" },
+            { "twd", "\u0646\u064a\u0648 \u062a\u0627\u0626\u064a\u0648\u0627\u0646 \u068a\u0627\u0644\u0631" },
+            { "ARS", "ARS" },
+            { "rsd", "\u0633\u0631\u0628\u064a\u0627 \u062f\u064a\u0646\u0627\u0631" },
+            { "QAR", "QAR" },
+            { "myr", "\u0645\u0644\u0627\u0626\u064a\u0634\u064a\u0627\u0626\u064a \u0631\u0646\u06af\u067d" },
+            { "IRR", "IRR" },
+            { "fkp", "\u0641\u0627\u06aa\u0644\u064a\u0646\u068a \u067b\u064a\u067d \u067e\u0627\u0626\u0648\u0646\u068a" },
+            { "xof", "\u0627\u0648\u0644\u0647\u0647 \u0622\u0641\u0631\u064a\u06aa\u0627 \u0641\u0631\u064a\u0646\u06aa" },
+            { "THB", "THB" },
+            { "UZS", "UZS" },
+            { "uyu", "\u064a\u0648\u0631\u0648\u06af\u0648\u0626\u064a \u067e\u064a\u0633\u0648" },
+            { "BDT", "BDT" },
+            { "cve", "\u06aa\u064a\u067e \u0648\u0631\u062f\u064a \u0627\u064a\u0633\u06aa\u0648\u068a\u0648" },
+            { "omr", "\u0639\u0645\u0627\u0646\u064a \u0631\u064a\u0627\u0644" },
+            { "LYD", "LYD" },
+            { "kes", "\u06aa\u064a\u0646\u064a\u0627\u0626\u064a \u0633\u0644\u0646\u06af" },
+            { "sek", "\u0633\u0648\u064a\u068a\u0646\u064a \u06aa\u0631\u0648\u0646\u0627" },
+            { "KWD", "KWD" },
+            { "btn", "\u0680\u0648\u067d\u0627\u0646\u064a \u06af\u0644\u067d\u0631\u0645" },
+            { "RUB", "RUB" },
+            { "gnf", "\u06af\u0646\u064a \u0641\u0631\u064a\u0646\u06aa" },
+            { "ISK", "ISK" },
+            { "mzn", "\u0645\u0648\u0632\u0645\u0628\u064a\u0642 \u0645\u064a\u067d\u064a\u06aa\u0644" },
+            { "ars", "\u0627\u0631\u062c\u0646\u067d\u0627\u0626\u0646 \u067e\u064a\u0633\u0648" },
+            { "qar", "\u0642\u0637\u0631\u064a \u0631\u064a\u0627\u0644" },
+            { "MKD", "MKD" },
+            { "irr", "\u0627\u064a\u0631\u0627\u0646\u064a \u0631\u064a\u0627\u0644" },
+            { "DZD", "DZD" },
+            { "thb", "\u067f\u0627\u0626\u064a \u0628\u0627\u0647\u062a" },
+            { "uzs", "\u0627\u0632\u0628\u06aa\u0633\u062a\u0627\u0646\u064a \u0633\u0648\u0645" },
+            { "xpf", "CFP \u0641\u0631\u064a\u0646\u06aa" },
+            { "PAB", "PAB" },
+            { "SGD", "SGD" },
+            { "bdt", "\u0628\u0646\u06af\u0644\u0627\u062f\u064a\u0634\u064a \u067d\u06aa\u0627" },
+            { "KGS", "KGS" },
+            { "lyd", "\u0644\u0628\u064a\u0627\u0626\u064a \u062f\u064a\u0646\u0627\u0631" },
+            { "kwd", "\u06aa\u0648\u064a\u062a\u064a \u062f\u064a\u0646\u0627\u0631" },
+            { "rub", "\u0631\u0648\u0633\u064a \u0631\u0628\u0644" },
+            { "CHF", "CHF" },
+            { "HRK", "HRK" },
+            { "isk", "\u0622\u0626\u064a\u0633 \u0644\u064a\u0646\u068a\u064a \u06aa\u0631\u0648\u0646\u0627" },
+            { "DJF", "DJF" },
+            { "mkd", "\u0645\u064a\u0633\u064a \u068a\u0648\u0646\u064a \u062f\u064a\u0646\u0627\u0631" },
+            { "TZS", "TZS" },
+            { "dzd", "\u0627\u0644\u062c\u064a\u0631\u064a\u0627\u0626\u064a \u062f\u064a\u0646\u0627\u0631" },
+            { "pab", "\u067e\u0627\u0646\u0627\u0645\u0627 \u067e\u0627\u0644\u0628\u0648\u0627" },
+            { "sgd", "\u0633\u0646\u06af\u0627\u067e\u0648\u0631\u064a \u068a\u0627\u0644\u0631" },
+            { "KHR", "KHR" },
+            { "IDR", "IDR" },
+            { "kgs", "\u06aa\u0631\u063a\u0632\u0633\u062a\u0627\u0646\u064a \u0633\u0648\u0645" },
+            { "KYD", "KYD" },
+            { "BWP", "BWP" },
+            { "SHP", "SHP" },
+            { "TJS", "TJS" },
+            { "xaf", "\u0648\u0686 \u0622\u0641\u0631\u064a\u06aa\u0627 \u0641\u0631\u064a\u0646\u06aa" },
+            { "AED", "AED" },
+            { "RWF", "RWF" },
+            { "chf", "\u0633\u0648\u0626\u0633 \u0641\u0631\u064a\u0646\u06aa" },
+            { "hrk", "\u06aa\u0631\u0648\u0634\u064a\u0627\u0626\u064a \u06aa\u0648\u0646\u0627" },
+            { "djf", "\u062c\u0628\u0648\u062a\u064a \u0641\u0631\u064a\u0646\u06aa" },
+            { "DKK", "DKK" },
+            { "BGN", "BGN" },
+            { "MMK", "MMK" },
+            { "NOK", "NOK" },
+            { "SYP", "SYP" },
+            { "tzs", "\u062a\u0646\u0632\u0627\u0646\u064a\u0627\u0626\u064a \u0634\u0644\u0646\u06af" },
+            { "vnd", "\u0648\u064a\u067d\u0646\u0627\u0645\u064a \u068a\u0648\u0646\u06af" },
+            { "aud", "\u0622\u0633\u067d\u0631\u064a\u0644\u0648\u064a \u068a\u0627\u0644\u0631" },
+            { "LKR", "LKR" },
+            { "khr", "\u06aa\u0645\u0628\u0648\u068a\u064a\u0627\u0626\u064a \u0631\u064a\u0627\u0644" },
+            { "CZK", "CZK" },
+            { "idr", "\u0627\u0646\u068a\u0648\u0646\u064a\u0634\u064a\u0627\u0626\u064a \u0631\u067e\u064a\u0647" },
+            { "kyd", "\u06aa\u064a\u0645\u064a\u0646 \u067b\u064a\u067d \u068a\u0627\u0644\u0631" },
+            { "HTG", "HTG" },
+            { "bwp", "\u0628\u0648\u0633\u062a\u0648\u0627\u0646\u064a \u067e\u0648\u0644\u0627" },
+            { "shp", "\u0633\u064a\u0646\u067d \u0647\u064a\u0644\u0646\u0627 \u067e\u0627\u0626\u0648\u0646\u068a" },
+            { "tjs", "\u062a\u0627\u062c\u06aa\u0633\u062a\u0627\u0646\u064a \u0633\u0648\u0645\u0648\u0646\u064a" },
+            { "BHD", "BHD" },
+            { "rwf", "\u0631\u0648\u0627\u0646\u068a\u0627 \u0641\u0631\u064a\u0646\u06aa" },
+            { "aed", "\u06af\u068f\u064a\u0644 \u0639\u0631\u0628 \u0627\u0645\u0627\u0631\u0627\u062a \u062f\u0631\u0647\u0645" },
+            { "KZT", "KZT" },
+            { "SZL", "SZL" },
+            { "dkk", "\u062f\u0627\u0646\u0634 \u06aa\u0631\u0648\u0646" },
+            { "YER", "YER" },
+            { "bgn", "\u0628\u0644\u063a\u0627\u0631\u06cc\u0646 \u0644\u06cc\u0648" },
+            { "AFN", "AFN" },
+            { "mmk", "\u0645\u064a\u0627\u0646\u0645\u0627\u0631 \u06aa\u064a\u0627\u067d" },
+            { "nok", "\u0646\u0627\u0631\u0648\u064a\u0627\u0626\u064a \u06aa\u0631\u0648\u0646" },
+            { "syp", "\u0633\u064a\u0631\u064a\u0627\u0626\u064a \u067e\u0627\u0626\u0648\u0646\u068a" },
+            { "AWG", "AWG" },
+            { "NPR", "NPR" },
+            { "MNT", "MNT" },
+            { "lkr", "\u0633\u0631\u064a \u0644\u0646\u06aa\u0646 \u0631\u067e\u064a" },
+            { "czk", "\u0686\u064a\u06aa \u06aa\u0631\u0648\u0646\u0627" },
+            { "BYN", "BYN" },
+            { "HUF", "HUF" },
+            { "xcd", "\u0627\u0648\u0680\u0631 \u06aa\u064a\u0631\u064a\u0628\u064a\u0646 \u068a\u0627\u0644\u0631" },
+            { "BYR", metaValue_BYR },
+            { "htg", "\u0647\u064a\u067d\u064a \u06af\u0648\u0631\u068a\u064a" },
+            { "BIF", "BIF" },
+            { "bhd", "\u0628\u062d\u0631\u064a\u0646\u064a \u062f\u064a\u0646\u0627\u0631" },
+            { "kzt", "\u0642\u0627\u0632\u0642\u0633\u062a\u0627\u0646 \u067d\u064a\u0646\u06af\u0627" },
+            { "szl", "\u0633\u0648\u0627\u0632\u064a \u0644\u0644\u0627\u0646\u06af\u064a\u0646\u064a" },
+            { "yer", "\u064a\u0645\u0646\u064a \u0631\u064a\u0627\u0644" },
+            { "afn", "\u0627\u0641\u063a\u0627\u0646\u064a \u0627\u0641\u063a\u0627\u0646\u064a" },
+            { "BZD", "BZD" },
+            { "MOP", "MOP" },
+            { "NAD", "NAD" },
+            { "awg", "\u0627\u0631\u0648\u0628\u0646 \u0641\u0644\u0648\u0631\u0646" },
+            { "npr", "\u0646\u064a\u067e\u0627\u0644\u064a \u0631\u067e\u064a" },
+            { "mnt", "\u0645\u0646\u06af\u0648\u0644\u064a \u062a\u062c\u0631\u06aa" },
+            { "gbp", "\u0628\u0631\u0637\u0627\u0646\u0648\u064a \u067e\u0627\u0626\u0648\u0646\u068a" },
+            { "byn", "\u0628\u06cc\u0644\u0627\u0631\u0648\u0633\u06cc \u0631\u0628\u0644" },
+            { "PEN", "PEN" },
+            { "huf", "\u0647\u0646\u06af\u064a\u0631\u064a\u0646 \u0641\u0648\u0631\u0646\u067d" },
+            { "WST", "WST" },
+            { "byr", metaValue_BYR },
+            { "TMT", "TMT" },
+            { "bif", "\u0628\u0631\u0648\u0646\u068a\u064a \u0641\u0631\u064a\u0646\u06aa" },
+            { "GTQ", "GTQ" },
+            { "CLP", "CLP" },
+            { "TND", "TND" },
+            { "bzd", "\u0628\u064a\u0644\u064a\u0632 \u068a\u0627\u0644\u0631" },
+            { "mop", "\u0645\u064a\u06aa\u0627\u0646\u064a\u0632 \u067e\u067d\u0627\u06aa\u0627" },
+            { "nad", "\u0646\u0645\u064a\u0628\u0627\u0626\u064a \u068a\u0627\u0644\u0631" },
+            { "SLL", "SLL" },
+            { "pen", "\u067e\u064a\u0631\u0648 \u0633\u0648\u0644" },
+            { "wst", "\u0633\u0627\u0645\u0648\u0622\u0646 \u067d\u0627\u0644\u0627" },
+            { "tmt", "\u062a\u0631\u06aa\u0645\u0627\u0646\u0633\u062a\u0627\u0646 \u0645\u0646\u062a" },
+            { "DOP", "DOP" },
+            { "KMF", "KMF" },
+            { "gtq", "\u06af\u0648\u0626\u067d\u064a \u0645\u0627\u0644\u0627 \u06aa\u067d\u0632\u0644" },
+            { "clp", "\u0686\u0644\u064a \u067e\u064a\u0633\u0648" },
+            { "tnd", "\u062a\u06cc\u0648\u0646\u0633 \u062f\u06cc\u0646\u0627\u0631" },
+            { "GEL", "GEL" },
+            { "MAD", "MAD" },
+            { "sll", "\u0633\u06cc\u0631\u0627 \u0644\u06cc\u0648\u0646\u064a\u0627\u0626\u064a \u0644\u06cc\u0648\u0646" },
+            { "TOP", "TOP" },
+            { "AZN", "AZN" },
+            { "PGK", "PGK" },
+            { "CNH", "CNH" },
+            { "UAH", "UAH" },
+            { "ERN", "ERN" },
+            { "dop", "\u068a\u0648\u0645\u064a\u0646\u064a\u06aa\u0646 \u067e\u064a\u0633\u0648" },
+            { "kmf", "\u06aa\u0648\u0645\u0648\u0631\u064a\u0627\u0626\u064a \u0641\u0631\u064a\u0646\u06aa" },
+            { "MRO", "MRO" },
+            { "gel", "\u062c\u0627\u0631\u062c\u064a\u0627\u0626\u064a \u0644\u0627\u0631\u064a" },
+            { "MRU", "MRU" },
+            { "mad", "\u0645\u0648\u0631\u0648\u06aa\u064a\u0627\u0626\u064a \u062f\u0631\u0647\u0645" },
+            { "azn", "\u0622\u0630\u0631\u0628\u0627\u0626\u064a\u062c\u0627\u0646\u064a \u0645\u0646\u062a" },
+            { "top", "\u062a\u0648\u0646\u06af\u0646 \u067e\u0627\u0646\u06af\u0627" },
+            { "pgk", "\u067e\u0627\u067e\u0648\u0627 \u0646\u064a\u0648 \u06af\u0646\u064a \u06aa\u0646\u0627" },
+            { "BMD", "BMD" },
+            { "PHP", "PHP" },
+            { "cnh", "\u0686\u064a\u0646\u064a \u064a\u0648\u0622\u0646 (\u063a\u064a\u0631 \u0645\u0644\u06aa\u064a)" },
+            { "uah", "\u06cc\u0648\u06aa\u0631\u0627\u0626\u0646 \u0647\u0631\u06cc\u0648\u0646\u06cc\u0627" },
+            { "PYG", "PYG" },
+            { "JMD", "JMD" },
+            { "ern", "\u0627\u064a\u0631\u064a\u067d\u064a\u0631\u064a\u0627\u0626\u064a \u0646\u0627\u06aa\u0641\u0627" },
+            { "COP", "COP" },
+            { "mro", "\u0645\u0648\u0631\u064a\u0634\u064a\u0627\u0626\u064a \u0627\u0648\u06af\u0648\u0626\u06cc\u0627 (1973\u20132017)" },
+            { "cny", "\u0686\u064a\u0646\u064a \u064a\u0648\u0622\u0646" },
+            { "mru", "\u0645\u0648\u0631\u064a\u0634\u064a\u0627\u0626\u064a \u0627\u0648\u06af\u0648\u0626\u06cc\u0627" },
+            { "ETB", "ETB" },
+            { "SOS", "SOS" },
+            { "VEF", "VEF" },
+            { "VUV", "VUV" },
+            { "LAK", "LAK" },
+            { "bmd", "\u0628\u0631\u0645\u0648\u062f\u064a \u068a\u0627\u0644\u0631" },
+            { "BND", "BND" },
+            { "php", "\u0641\u0644\u067e\u0627\u0626\u0646\u064a \u067e\u064a\u0633\u0648" },
+            { "xxx", "\u0627\u06bb\u0684\u0627\u062a\u0644 \u0633\u06aa\u0648" },
+            { "LRD", "LRD" },
+            { "pyg", "\u067e\u064a\u0631\u0627\u06af\u0648\u0626\u064a \u06af\u0627\u0631\u0627\u0646\u064a" },
+            { "jmd", "\u062c\u0645\u064a\u06aa\u0627\u0626\u064a \u068a\u0627\u0644\u0631" },
+            { "ALL", "ALL" },
+            { "ZMW", "ZMW" },
+            { "cop", "\u06aa\u0648\u0644\u0645\u0628\u064a\u0627\u0626\u064a \u067e\u064a\u0633\u0648" },
+            { "usd", "\u0622\u0645\u0631\u064a\u06aa\u064a \u068a\u0627\u0644\u0631" },
+            { "etb", "\u0627\u064a\u067f\u0648\u067e\u064a\u0627\u0626\u064a \u0628\u0631" },
+            { "GHS", "GHS" },
+            { "GYD", "GYD" },
+            { "KPW", "KPW" },
+            { "BOB", "BOB" },
+            { "MDL", "MDL" },
+            { "sos", "\u0633\u0648\u0645\u0627\u0644\u064a \u0634\u0644\u0646\u06af" },
+            { "vef", "Venezuelan Bol\u00edvar (2008\u20132018)" },
+            { "vuv", "\u0648\u0627\u0646\u0648\u0627\u062a\u0648 \u0648\u0627\u062a\u0648" },
+            { "lak", "\u0644\u0627\u0626\u0648\u0634\u064a\u0627\u0626\u064a \u06aa\u067e" },
+            { "AMD", "AMD" },
+            { "bnd", "\u0628\u0631\u0648\u0646\u0627\u0626\u064a \u068a\u0627\u0644\u0631" },
+            { "TRY", "TRY" },
+            { "LBP", "LBP" },
+            { "JOD", "JOD" },
+            { "lrd", "\u0644\u0627\u0626\u0628\u06cc\u0631\u06cc\u0627\u0626\u06cc \u068a\u0627\u0644\u0631" },
+            { "all", "\u0627\u0644\u0628\u0627\u0646\u064a \u0644\u064a\u06aa" },
+            { "ves", "\u0648\u06cc\u0646\u0632\u0648\u06cc\u0644\u0627 \u0628\u0648\u0644\u06cc\u0648\u0631" },
             { "zmw", "\u0632\u0645\u0628\u0627\u0626\u064a \u06aa\u0648\u0627\u0686\u0627" },
+            { "MUR", "MUR" },
+            { "GIP", "GIP" },
+            { "RON", "RON" },
+            { "ils", "\u0627\u0633\u0631\u0627\u0626\u064a\u0644\u064a \u0646\u064a\u0648 \u0634\u064a\u06aa\u0644" },
+            { "ghs", "\u06af\u0647\u0627\u0646\u064a\u0646 \u0633\u064a\u062f\u064a" },
+            { "gyd", "\u06af\u064a\u0627\u0646\u0627 \u068a\u0627\u0644\u0631" },
+            { "kpw", "\u0627\u062a\u0631 \u06aa\u0648\u0631\u064a\u0627\u0626\u064a \u0648\u0646" },
+            { "NGN", "NGN" },
+            { "bob", "\u0628\u0648\u0644\u06cc\u0648\u06cc\u0646 \u0628\u0648\u0644\u06cc\u0648\u06cc\u0627\u0646\u0648" },
+            { "mdl", "\u0645\u0627\u0644\u062f\u064a\u067e \u0644\u064a\u0648" },
+            { "CRC", "CRC" },
+            { "PKR", "Rs" },
+            { "amd", "\u0627\u0631\u0645\u0627\u0646\u064a \u068a\u0631\u0645" },
+            { "ANG", "ANG" },
+            { "try", "\u062a\u0631\u06aa\u064a \u0644\u0631\u0627" },
+            { "lbp", "\u0644\u0628\u0646\u0627\u0646\u064a \u067e\u0627\u0626\u0648\u0646\u068a" },
+            { "jod", "\u0627\u0631\u062f\u0646\u064a \u062f\u064a\u0646\u0627\u0631" },
+            { "hkd", "\u0647\u0627\u0646\u06af \u06aa\u0627\u0646\u06af \u068a\u0627\u0644\u0631" },
+            { "eur", "\u064a\u0648\u0631\u0648" },
+            { "SRD", "SRD" },
+            { "SAR", "SAR" },
+            { "TTD", "TTD" },
+            { "cad", "\u06aa\u0626\u064a\u0646\u068a\u064a\u0627\u0626\u064a \u068a\u0627\u0644\u0631" },
+            { "MVR", "MVR" },
+            { "mur", "\u0645\u0627\u0631\u064a\u0634\u064a\u0627\u0626\u064a \u0631\u067e\u064a" },
+            { "gip", "\u062c\u0628\u0631\u0627\u0644\u067d\u0631 \u067e\u0627\u0626\u0648\u0646\u068a" },
+            { "ron", "\u0631\u0648\u0645\u0627\u0646\u06cc\u0627\u0626\u064a \u0644\u06cc\u0648" },
+            { "AOA", "AOA" },
+            { "PLN", "PLN" },
+            { "SBD", "SBD" },
+            { "ngn", "\u0646\u0627\u0626\u062c\u0631\u064a\u0627\u0626\u064a \u0646\u0627\u0626\u0631\u0627" },
+            { "crc", "\u06aa\u0648\u0633\u067d\u0627 \u0631\u064a\u06aa\u0627 \u06aa\u0648\u0644\u0646" },
+            { "pkr", "\u067e\u0627\u06aa\u0633\u062a\u0627\u0646\u064a \u0631\u067e\u064a" },
+            { "ang", "\u0646\u064a\u068c\u0631\u0644\u064a\u0646\u068a \u0627\u0646\u067d\u0644\u064a\u0626\u0646 \u06af\u0644\u068a\u0631" },
+            { "MWK", "MWK" },
+            { "srd", "\u0633\u0631\u064a\u0646\u0627\u0645\u064a \u068a\u0627\u0644\u0631" },
+            { "sar", "\u0633\u0639\u0648\u062f\u064a \u0631\u064a\u0627\u0644" },
+            { "ttd", "\u067d\u0631\u064a\u0646\u068a\u064a\u068a \u06fd \u067d\u0648\u0628\u0627\u06af\u0648 \u068a\u0627\u0644\u0631" },
+            { "MGA", "MGA" },
+            { "mvr", "\u0645\u0627\u0644\u062f\u064a\u067e \u0631\u0648\u0641\u064a\u0627" },
+            { "inr", "\u0627\u0646\u068a\u064a\u0646 \u0631\u067e\u064a" },
+            { "BAM", "BAM" },
+            { "EGP", "EGP" },
+            { "SSP", "SSP" },
+            { "krw", "\u068f\u06a9\u06bb \u06aa\u0648\u0631\u064a\u0627\u0626\u064a \u0648\u0646" },
+            { "aoa", "\u0627\u0646\u06af\u0648\u0644\u064a\u0627\u0626\u064a \u06aa\u0648\u0627\u0646\u0632\u0627" },
+            { "jpy", "\u062c\u0627\u067e\u0627\u0646\u064a \u064a\u064a\u0646" },
+            { "pln", "\u067e\u0648\u0644\u0634 \u0632\u0644\u0627\u067d\u064a" },
+            { "sbd", "\u0633\u0648\u0644\u0648\u0645\u0627\u0646 \u067b\u064a\u067d \u068a\u0627\u0644\u0631" },
+            { "NIO", "NIO" },
         };
         return data;
     }
