@@ -135,7 +135,7 @@ public class LocaleNames_fr extends OpenListResourceBundle {
             { "type.ca.ethiopic", "calendrier \u00e9thiopien" },
             { "glk", "gilaki" },
             { "AI", "Anguilla" },
-            { "key.tz", "Fuseau horaire" },
+            { "key.tz", "fuseau horaire" },
             { "AL", "Albanie" },
             { "AM", "Arm\u00e9nie" },
             { "Teng", "tengwar" },
@@ -266,7 +266,7 @@ public class LocaleNames_fr extends OpenListResourceBundle {
             { "FJ", "Fidji" },
             { "FK", "\u00celes Malouines" },
             { "FM", "\u00c9tats f\u00e9d\u00e9r\u00e9s de Micron\u00e9sie" },
-            { "key.va", "Variante locale" },
+            { "key.va", "variante locale" },
             { "FO", "\u00celes F\u00e9ro\u00e9" },
             { "Taml", metaValue_ta },
             { "FR", "France" },
