@@ -96,6 +96,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
         final String metaValue_arc = "arameisk";
         final String metaValue_ban = "balinesisk";
         final String metaValue_bug = "buginesisk";
+        final String metaValue_ccp = "chakma";
         final String metaValue_cop = "koptisk";
         final String metaValue_got = "gotisk";
         final String metaValue_kpe = "kpelle";
@@ -121,6 +122,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "Zsye", "emoji" },
             { "%%NJIVA", "gniva- og njivadialekt" },
             { "xmf", "mingrelsk" },
+            { "ccp", metaValue_ccp },
             { "egy", "gammelegyptisk" },
             { "raj", "rajasthani" },
             { "Phag", "phags-pa" },
@@ -275,7 +277,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "FJ", "Fiji" },
             { "FK", "Falklands\u00f8yene" },
             { "FM", "Mikronesiaf\u00f8derasjonen" },
-            { "key.va", "Spr\u00e5kvariant" },
+            { "key.va", "spr\u00e5kvariant" },
             { "FO", "F\u00e6r\u00f8yene" },
             { "Taml", "tamilsk" },
             { "FR", "Frankrike" },
@@ -406,6 +408,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "LC", "St. Lucia" },
             { "Cyrs", "kirkeslavisk kyrillisk" },
             { "gwi", "gwichin" },
+            { "%%LUNA1918", "LUNA1918" },
             { "nds", "nedertysk" },
             { "LI", "Liechtenstein" },
             { "LK", "Sri Lanka" },
@@ -495,6 +498,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "crh", "krimtatarisk" },
             { "ang", "gammelengelsk" },
             { "OM", "Oman" },
+            { "%%PETR1708", "PETR1708" },
             { "anp", "angika" },
             { "crs", "seselwa" },
             { "Xpeo", metaValue_peo },
@@ -695,7 +699,9 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "type.nu.mtei", "meetei mayek-tall" },
             { "wal", "wolaytta" },
             { "was", "washo" },
+            { "XA", "pseudospr\u00e5k \u2013 aksenter" },
             { "war", "waray-waray" },
+            { "XB", "pseudospr\u00e5k \u2013 RTL" },
             { "awa", "avadhi" },
             { "061", "Polynesia" },
             { "%%KSCOR", "standard ortografi" },
@@ -959,6 +965,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "ig", "ibo" },
             { "ii", "sichuan-yi" },
             { "frm", "mellomfransk" },
+            { "%%RUMGR", "RUMGR" },
             { "ik", "inupiak" },
             { "fro", "gammelfransk" },
             { "frp", "arpitansk" },
@@ -1195,9 +1202,9 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "dyo", "jola-fonyi" },
             { "type.nu.jpan", "japanske tall" },
             { "tr", "tyrkisk" },
+            { "Cakm", metaValue_ccp },
             { "ts", "tsonga" },
             { "swb", "komorisk" },
-            { "Cakm", "chakma" },
             { "tt", "tatarisk" },
             { "dyu", "dyula" },
             { "tw", "twi" },
@@ -1341,6 +1348,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "mua", "mundang" },
             { "type.nu.guru", "gurmukhi-sifre" },
             { "mul", "flere spr\u00e5k" },
+            { "%%PUTER", "PUTER" },
             { "cad", "caddo" },
             { "key.ms", "m\u00e5lesystem" },
             { "mus", "creek" },
