@@ -623,7 +623,7 @@ public class LocaleNames_zh_Hant extends OpenListResourceBundle {
             { "SX", "\u8377\u5c6c\u8056\u99ac\u4e01" },
             { "SY", "\u6558\u5229\u4e9e" },
             { "yao", "\u7464\u6587" },
-            { "SZ", "\u53f2\u74e6\u6fdf\u862d" },
+            { "SZ", "\u53f2\u74e6\u5e1d\u5c3c" },
             { "arw", "\u963f\u62c9\u74e6\u514b\u6587" },
             { "arz", "\u57c3\u53ca\u963f\u62c9\u4f2f\u6587" },
             { "ary", "\u6469\u6d1b\u54e5\u963f\u62c9\u4f2f\u6587" },
