@@ -487,7 +487,7 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
                "",
             };
         final String[] French_Southern = new String[] {
-               "hora de las Tierras Australes y Ant\u00e1rticas Francesas",
+               "hora de Ant\u00e1rtida y Territorios Australes Franceses",
                "",
                "",
                "",
@@ -887,7 +887,7 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
                "",
             };
         final String[] Myanmar = new String[] {
-               "hora de Myanmar (Birmania)",
+               "hora de Myanmar",
                "",
                "",
                "",
@@ -1824,7 +1824,7 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
             { "Europe/Kaliningrad", Europe_Eastern },
             { "timezone.excity.Asia/Magadan", "Magad\u00e1n" },
             { "timezone.excity.Pacific/Wake", "Wake" },
-            { "timezone.excity.Atlantic/Canary", "Islas Canarias" },
+            { "timezone.excity.Atlantic/Canary", "Canarias" },
             { "Africa/Mogadishu", Africa_Eastern },
             { "timezone.excity.America/Glace_Bay", "Glace Bay" },
             { "timezone.excity.Africa/Casablanca", "Casablanca" },
