@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -246,6 +246,14 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Irkutsk = new String[] {
+               "hora est\u00e1ndar de Irkutsh",
+               "",
+               "hora de verano de Irkutsh",
+               "",
+               "hora de Irkutsk",
+               "",
+            };
         final String[] Apia = new String[] {
                "hora est\u00e1ndar de Apia",
                "",
@@ -254,6 +262,22 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
                "hora de Apia",
                "",
             };
+        final String[] Christmas = new String[] {
+               "hora de la isla de Navidad",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Cook = new String[] {
+               "hora est\u00e1ndar de las Islas Cook",
+               "",
+               "hora de verano media de las Islas Cook",
+               "",
+               "hora de las Islas Cook",
+               "",
+            };
         final Object[][] data = new Object[][] {
             { "America/Los_Angeles", America_Pacific },
             { "America/Denver", America_Mountain },
@@ -312,6 +336,7 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
                 }
             },
             { "Africa/Cairo", Europe_Eastern },
+            { "Pacific/Rarotonga", Cook },
             { "America/Aruba", Atlantic },
             { "America/North_Dakota/Center", America_Central },
             { "America/Guatemala", America_Central },
@@ -327,7 +352,6 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
             { "America/Tegucigalpa", America_Central },
             { "Asia/Damascus", Europe_Eastern },
             { "Europe/Zaporozhye", Europe_Eastern },
-            { "timezone.excity.Asia/Dushanbe", "Dusamb\u00e9" },
             { "Atlantic/Madeira", Europe_Western },
             { "Antarctica/Palmer",
                 new String[] {
@@ -360,6 +384,7 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
             { "America/Matamoros", America_Central },
             { "America/Blanc-Sablon", Atlantic },
             { "Europe/Kaliningrad", Europe_Eastern },
+            { "timezone.excity.Pacific/Wake", "Wake" },
             { "Europe/Lisbon", Europe_Western },
             { "CST6CDT", America_Central },
             { "Pacific/Easter", Easter },
@@ -416,6 +441,7 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
             { "America/Louisville", America_Eastern },
             { "America/Lower_Princes", Atlantic },
             { "America/Vancouver", America_Pacific },
+            { "timezone.excity.Asia/Almaty", "Almat\u00fd" },
             { "America/Detroit", America_Eastern },
             { "Pacific/Johnston", Hawaii_Aleutian },
             { "America/Thule", Atlantic },
@@ -460,15 +486,17 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Goose_Bay", Atlantic },
             { "America/Swift_Current", America_Central },
+            { "timezone.excity.Asia/Pyongyang", "Piongyang" },
             { "America/Metlakatla", Alaska },
             { "America/Pangnirtung", America_Eastern },
             { "Europe/Sofia", Europe_Eastern },
             { "America/Indiana/Vincennes", America_Eastern },
             { "America/Whitehorse", America_Pacific },
             { "America/Kralendijk", Atlantic },
+            { "Indian/Christmas", Christmas },
             { "America/Antigua", Atlantic },
             { "America/Montreal", America_Eastern },
-            { "timezone.excity.America/Sao_Paulo", "S\u00e3o Paulo" },
+            { "timezone.excity.Pacific/Honolulu", "Honolulu" },
             { "America/Inuvik", America_Mountain },
             { "America/Iqaluit", America_Eastern },
             { "Antarctica/Macquarie", Macquarie },
@@ -478,7 +506,6 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
             { "SystemV/MST7MDT", America_Mountain },
             { "America/St_Vincent", Atlantic },
             { "Asia/Gaza", Europe_Eastern },
-            { "timezone.excity.Africa/Accra", "Acra" },
             { "PST8PDT", America_Pacific },
             { "America/Grenada", Atlantic },
             { "Atlantic/Faeroe", Europe_Western },
@@ -529,12 +556,14 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
             { "America/North_Dakota/New_Salem", America_Central },
             { "Pacific/Guam", Chamorro },
             { "Pacific/Wake", Wake },
+            { "Asia/Irkutsk", Irkutsk },
             { "Atlantic/Bermuda", Atlantic },
             { "America/Costa_Rica", America_Central },
             { "America/Dawson", America_Pacific },
             { "America/Shiprock", America_Mountain },
             { "America/Winnipeg", America_Central },
             { "America/Indiana/Knox", America_Central },
+            { "timezone.excity.America/Rio_Branco", "Rio Branco" },
             { "America/North_Dakota/Beulah", America_Central },
             { "timezone.excity.Europe/Ulyanovsk", "Ulyanovsk" },
             { "Asia/Amman", Europe_Eastern },
