@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -217,9 +217,9 @@ public class TimeZoneNames_et extends TimeZoneNamesBundle {
         final String[] Yekaterinburg = new String[] {
                "Jekaterinburgi standardaeg",
                "",
-               "Jakaterinburgi suveaeg",
+               "Jekaterinburgi suveaeg",
                "",
-               "Jakaterinburgi aeg",
+               "Jekaterinburgi aeg",
                "",
             };
         final String[] Maldives = new String[] {
@@ -318,14 +318,6 @@ public class TimeZoneNames_et extends TimeZoneNamesBundle {
                "Falklandi saarte aeg",
                "",
             };
-        final String[] Bhutan = new String[] {
-               "Bhutani aeg",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Apia = new String[] {
                "Apia standardaeg",
                "",
@@ -334,6 +326,14 @@ public class TimeZoneNames_et extends TimeZoneNamesBundle {
                "Apia aeg",
                "",
             };
+        final String[] Bhutan = new String[] {
+               "Bhutani aeg",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Nauru = new String[] {
                "Nauru aeg",
                "",
@@ -574,12 +574,12 @@ public class TimeZoneNames_et extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Colombia = new String[] {
-               "Colombia standardaeg",
+        final String[] Australia_Eastern = new String[] {
+               "Ida-Austraalia standardaeg",
                "",
-               "Colombia suveaeg",
+               "Ida-Austraalia suveaeg",
                "",
-               "Colombia aeg",
+               "Ida-Austraalia aeg",
                "",
             };
         final String[] French_Guiana = new String[] {
@@ -590,12 +590,12 @@ public class TimeZoneNames_et extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Australia_Eastern = new String[] {
-               "Ida-Austraalia standardaeg",
+        final String[] Colombia = new String[] {
+               "Colombia standardaeg",
                "",
-               "Ida-Austraalia suveaeg",
+               "Colombia suveaeg",
                "",
-               "Ida-Austraalia aeg",
+               "Colombia aeg",
                "",
             };
         final String[] Chile = new String[] {
@@ -710,16 +710,8 @@ public class TimeZoneNames_et extends TimeZoneNamesBundle {
                "Paraguay aeg",
                "",
             };
-        final String[] Casey = new String[] {
-               "Casey aeg",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Malaysia = new String[] {
-               "Malaisia \u200b\u200baeg",
+               "Malaisia aeg",
                "",
                "",
                "",
@@ -1062,12 +1054,12 @@ public class TimeZoneNames_et extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "Loode-Mehhiko standardaeg",
+        final String[] Volgograd = new String[] {
+               "Volgogradi standardaeg",
                "",
-               "Loode-Mehhiko suveaeg",
+               "Volgogradi suveaeg",
                "",
-               "Loode-Mehhiko aeg",
+               "Volgogradi aeg",
                "",
             };
         final String[] Easter = new String[] {
@@ -1078,6 +1070,14 @@ public class TimeZoneNames_et extends TimeZoneNamesBundle {
                "Lihav\u00f5ttesaare aeg",
                "",
             };
+        final String[] Mexico_Northwest = new String[] {
+               "Loode-Mehhiko standardaeg",
+               "",
+               "Loode-Mehhiko suveaeg",
+               "",
+               "Loode-Mehhiko aeg",
+               "",
+            };
         final String[] DumontDUrville = new String[] {
                "Dumont-d\u2019Urville\u2019i aeg",
                "",
@@ -1230,14 +1230,6 @@ public class TimeZoneNames_et extends TimeZoneNamesBundle {
                "Samara aeg",
                "",
             };
-        final String[] Pyongyang = new String[] {
-               "Pyongyangi aeg",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] India = new String[] {
                "India aeg",
                "",
@@ -1268,7 +1260,16 @@ public class TimeZoneNames_et extends TimeZoneNamesBundle {
             { "America/St_Johns", Newfoundland },
             { "Europe/Paris", Europe_Central },
             { "GMT", GMT },
-            { "Africa/Casablanca", Europe_Western },
+            { "Africa/Casablanca",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "Asia/Jerusalem", Israel },
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
@@ -1352,7 +1353,6 @@ public class TimeZoneNames_et extends TimeZoneNamesBundle {
             { "Antarctica/McMurdo", New_Zealand },
             { "timezone.excity.America/Nome", "Nome" },
             { "Pacific/Tahiti", Tahiti },
-            { "HST", Hawaii_Aleutian },
             { "timezone.excity.America/Vancouver", "Vancouver" },
             { "timezone.excity.America/Matamoros", "Matamoros" },
             { "Africa/Asmera", Africa_Eastern },
@@ -1462,12 +1462,12 @@ public class TimeZoneNames_et extends TimeZoneNamesBundle {
             { "timezone.excity.America/Sao_Paulo", "S\u00e3o Paulo" },
             { "Pacific/Gambier", Gambier },
             { "Africa/Gaborone", Africa_Central },
-            { "Asia/Pyongyang", Pyongyang },
+            { "Asia/Pyongyang", Korea },
             { "timezone.excity.America/New_York", "New York" },
             { "Asia/Gaza", Europe_Eastern },
             { "timezone.excity.Africa/Accra", "Accra" },
             { "timezone.excity.Etc/Unknown", "m\u00e4\u00e4ramata linn" },
-            { "Asia/Qyzylorda", Kazakhstan_Eastern },
+            { "Asia/Qyzylorda", Kazakhstan_Western },
             { "timezone.excity.America/Thule", "Thule" },
             { "timezone.excity.America/Grand_Turk", "Grand Turk" },
             { "America/Yakutat", Alaska },
@@ -1528,8 +1528,17 @@ public class TimeZoneNames_et extends TimeZoneNamesBundle {
             { "Asia/Vladivostok", Vladivostok },
             { "timezone.excity.Atlantic/St_Helena", "Saint Helena" },
             { "Africa/Maputo", Africa_Central },
-            { "Africa/El_Aaiun", Europe_Western },
             { "Africa/Ouagadougou", GMT },
+            { "Africa/El_Aaiun",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "timezone.excity.Pacific/Rarotonga", "Rarotonga" },
             { "timezone.excity.Europe/Luxembourg", "Luxembourg" },
             { "America/Cayman", America_Eastern },
@@ -1686,7 +1695,6 @@ public class TimeZoneNames_et extends TimeZoneNamesBundle {
             { "timezone.excity.America/Goose_Bay", "Goose Bay" },
             { "timezone.excity.America/Eirunepe", "Eirunep\u00e9" },
             { "timezone.excity.America/Los_Angeles", "Los Angeles" },
-            { "MST", America_Mountain },
             { "America/Whitehorse", America_Pacific },
             { "timezone.excity.America/Cuiaba", "Cuiab\u00e1" },
             { "Pacific/Noumea", New_Caledonia },
@@ -1723,6 +1731,7 @@ public class TimeZoneNames_et extends TimeZoneNamesBundle {
             { "America/Caracas", Venezuela },
             { "Asia/Hebron", Europe_Eastern },
             { "SystemV/PST8PDT", America_Pacific },
+            { "timezone.excity.Asia/Qostanay", "Kostanaj" },
             { "Africa/Monrovia", GMT },
             { "Asia/Ust-Nera", Vladivostok },
             { "timezone.excity.America/Louisville", "Louisville" },
@@ -1894,7 +1903,7 @@ public class TimeZoneNames_et extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "Africa/Sao_Tome", Africa_Western },
+            { "Africa/Sao_Tome", GMT },
             { "Indian/Chagos", Indian_Ocean },
             { "timezone.excity.America/Metlakatla", "Metlakatla" },
             { "Asia/Yakutsk", Yakutsk },
@@ -1919,7 +1928,7 @@ public class TimeZoneNames_et extends TimeZoneNamesBundle {
             { "America/Metlakatla", Alaska },
             { "timezone.excity.Europe/Athens", "Ateena" },
             { "Africa/Djibouti", Africa_Eastern },
-            { "EST", America_Eastern },
+            { "Asia/Qostanay", Kazakhstan_Eastern },
             { "Europe/Simferopol", Moscow },
             { "Europe/Sofia", Europe_Eastern },
             { "Africa/Nouakchott", GMT },
@@ -1941,7 +1950,7 @@ public class TimeZoneNames_et extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Jerusalem", "Jeruusalemm" },
             { "Atlantic/Faeroe", Europe_Western },
             { "timezone.excity.Asia/Riyadh", "Ar-Riy\u0101\u1e11" },
-            { "Antarctica/Casey", Casey },
+            { "Antarctica/Casey", Australia_Western },
             { "Europe/Copenhagen", Europe_Central },
             { "timezone.excity.Africa/Bangui", "Bangui" },
             { "timezone.excity.Africa/Lusaka", "Lusaka" },
@@ -2103,7 +2112,7 @@ public class TimeZoneNames_et extends TimeZoneNamesBundle {
             { "Indian/Mayotte", Africa_Eastern },
             { "timezone.excity.America/St_Thomas", "Saint Thomas" },
             { "timezone.excity.Europe/Busingen", "B\u00fcsingen" },
-            { "Europe/Volgograd", Moscow },
+            { "Europe/Volgograd", Volgograd },
             { "America/Lower_Princes", Atlantic },
             { "timezone.excity.Europe/Istanbul", "\u0130stanbul" },
             { "America/Rio_Branco", Acre },
