@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -71,11 +71,11 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
     @Override
     protected final Object[][] getContents() {
         final String[] Moscow = new String[] {
-               "czas moskiewski standardowy",
+               "Moskwa (czas standardowy)",
                "",
-               "czas moskiewski letni",
+               "Moskwa (czas letni)",
                "",
-               "czas moskiewski",
+               "Moskwa",
                "",
             };
         final String[] Pakistan = new String[] {
@@ -310,14 +310,6 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
                "Falklandy",
                "",
             };
-        final String[] Bhutan = new String[] {
-               "Bhutan",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Apia = new String[] {
                "Apia (czas standardowy)",
                "",
@@ -326,6 +318,14 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
                "Apia",
                "",
             };
+        final String[] Bhutan = new String[] {
+               "Bhutan",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Nauru = new String[] {
                "Nauru",
                "",
@@ -566,12 +566,12 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Colombia = new String[] {
-               "Kolumbia (czas standardowy)",
+        final String[] Australia_Eastern = new String[] {
+               "czas wschodnioaustralijski standardowy",
                "",
-               "Kolumbia (czas letni)",
+               "czas wschodnioaustralijski letni",
                "",
-               "Kolumbia",
+               "czas wschodnioaustralijski",
                "",
             };
         final String[] French_Guiana = new String[] {
@@ -582,12 +582,12 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Australia_Eastern = new String[] {
-               "czas wschodnioaustralijski standardowy",
+        final String[] Colombia = new String[] {
+               "Kolumbia (czas standardowy)",
                "",
-               "czas wschodnioaustralijski letni",
+               "Kolumbia (czas letni)",
                "",
-               "czas wschodnioaustralijski",
+               "Kolumbia",
                "",
             };
         final String[] Chile = new String[] {
@@ -1046,12 +1046,12 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "Meksyk P\u00f3\u0142nocno-Zachodni (czas standardowy)",
+        final String[] Volgograd = new String[] {
+               "Wo\u0142gograd (czas standardowy)",
                "",
-               "Meksyk P\u00f3\u0142nocno-Zachodni (czas letni)",
+               "Wo\u0142gograd (czas letni)",
                "",
-               "Meksyk P\u00f3\u0142nocno-Zachodni",
+               "Wo\u0142gograd",
                "",
             };
         final String[] Easter = new String[] {
@@ -1062,6 +1062,14 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
                "Wyspa Wielkanocna",
                "",
             };
+        final String[] Mexico_Northwest = new String[] {
+               "Meksyk P\u00f3\u0142nocno-Zachodni (czas standardowy)",
+               "",
+               "Meksyk P\u00f3\u0142nocno-Zachodni (czas letni)",
+               "",
+               "Meksyk P\u00f3\u0142nocno-Zachodni",
+               "",
+            };
         final String[] DumontDUrville = new String[] {
                "Dumont-d\u2019Urville",
                "",
@@ -1214,16 +1222,8 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
                "czas Samara",
                "",
             };
-        final String[] Pyongyang = new String[] {
-               "Pjongjang",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] India = new String[] {
-               "czas indyjski",
+               "czas indyjski standardowy",
                "",
                "",
                "",
@@ -1252,7 +1252,16 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
             { "America/St_Johns", Newfoundland },
             { "Europe/Paris", Europe_Central },
             { "GMT", GMT },
-            { "Africa/Casablanca", Europe_Western },
+            { "Africa/Casablanca",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "Asia/Jerusalem", Israel },
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
@@ -1335,7 +1344,6 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
             { "Antarctica/McMurdo", New_Zealand },
             { "timezone.excity.America/Nome", "Nome" },
             { "Pacific/Tahiti", Tahiti },
-            { "HST", Hawaii_Aleutian },
             { "timezone.excity.America/Vancouver", "Vancouver" },
             { "timezone.excity.America/Matamoros", "Matamoros" },
             { "Africa/Asmera", Africa_Eastern },
@@ -1445,12 +1453,12 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
             { "timezone.excity.America/Sao_Paulo", "Sao Paulo" },
             { "Pacific/Gambier", Gambier },
             { "Africa/Gaborone", Africa_Central },
-            { "Asia/Pyongyang", Pyongyang },
+            { "Asia/Pyongyang", Korea },
             { "timezone.excity.America/New_York", "Nowy Jork" },
             { "Asia/Gaza", Europe_Eastern },
             { "timezone.excity.Africa/Accra", "Akra" },
             { "timezone.excity.Etc/Unknown", "Nieznane miasto" },
-            { "Asia/Qyzylorda", Kazakhstan_Eastern },
+            { "Asia/Qyzylorda", Kazakhstan_Western },
             { "timezone.excity.America/Thule", "Qaanaaq" },
             { "timezone.excity.America/Grand_Turk", "Grand Turk" },
             { "America/Yakutat", Alaska },
@@ -1511,8 +1519,17 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
             { "Asia/Vladivostok", Vladivostok },
             { "timezone.excity.Atlantic/St_Helena", "\u015awi\u0119ta Helena" },
             { "Africa/Maputo", Africa_Central },
-            { "Africa/El_Aaiun", Europe_Western },
             { "Africa/Ouagadougou", GMT },
+            { "Africa/El_Aaiun",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "timezone.excity.Pacific/Rarotonga", "Rarotonga" },
             { "timezone.excity.Europe/Luxembourg", "Luksemburg" },
             { "America/Cayman", America_Eastern },
@@ -1670,7 +1687,6 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
             { "timezone.excity.America/Goose_Bay", "Goose Bay" },
             { "timezone.excity.America/Eirunepe", "Eirunepe" },
             { "timezone.excity.America/Los_Angeles", "Los Angeles" },
-            { "MST", America_Mountain },
             { "America/Whitehorse", America_Pacific },
             { "timezone.excity.America/Cuiaba", "Cuiab\u00e1" },
             { "Pacific/Noumea", New_Caledonia },
@@ -1707,6 +1723,7 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
             { "America/Caracas", Venezuela },
             { "Asia/Hebron", Europe_Eastern },
             { "SystemV/PST8PDT", America_Pacific },
+            { "timezone.excity.Asia/Qostanay", "Kustanaj" },
             { "Africa/Monrovia", GMT },
             { "Asia/Ust-Nera", Vladivostok },
             { "timezone.excity.America/Louisville", "Louisville" },
@@ -1878,7 +1895,7 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "Africa/Sao_Tome", Africa_Western },
+            { "Africa/Sao_Tome", GMT },
             { "Indian/Chagos", Indian_Ocean },
             { "timezone.excity.America/Metlakatla", "Metlakatla" },
             { "Asia/Yakutsk", Yakutsk },
@@ -1903,7 +1920,7 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
             { "America/Metlakatla", Alaska },
             { "timezone.excity.Europe/Athens", "Ateny" },
             { "Africa/Djibouti", Africa_Eastern },
-            { "EST", America_Eastern },
+            { "Asia/Qostanay", Kazakhstan_Eastern },
             { "Europe/Simferopol", Moscow },
             { "Europe/Sofia", Europe_Eastern },
             { "Africa/Nouakchott", GMT },
@@ -1925,6 +1942,7 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Jerusalem", "Jerozolima" },
             { "Atlantic/Faeroe", Europe_Western },
             { "timezone.excity.Asia/Riyadh", "Rijad" },
+            { "Antarctica/Casey", Australia_Western },
             { "Europe/Copenhagen", Europe_Central },
             { "timezone.excity.Africa/Bangui", "Bangi" },
             { "timezone.excity.Africa/Lusaka", "Lusaka" },
@@ -2086,7 +2104,7 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
             { "Indian/Mayotte", Africa_Eastern },
             { "timezone.excity.America/St_Thomas", "Saint Thomas" },
             { "timezone.excity.Europe/Busingen", "B\u00fcsingen am Hochrhein" },
-            { "Europe/Volgograd", Moscow },
+            { "Europe/Volgograd", Volgograd },
             { "America/Lower_Princes", Atlantic },
             { "timezone.excity.Europe/Istanbul", "Stambu\u0142" },
             { "timezone.excity.Europe/Sarajevo", "Sarajewo" },
