@@ -86,6 +86,22 @@ public class TimeZoneNames_yo_BJ extends TimeZoneNamesBundle {
                "\u00c0k\u00f3k\u00f2 \u00ech\u00e0 \u00ecl\u00e0 o\u00f2r\u00f9n",
                "",
             };
+        final String[] America_Central = new String[] {
+               "\u00e0k\u00f3k\u00f2 asiko \u00e0\u00e1r\u00edn gb\u00f9ngb\u00f9n",
+               "",
+               "Ak\u00f3k\u00f2 \u00e0\u00e1r\u00edn gb\u00f9ngb\u00f9n oj\u00fam\u0254m\u0254",
+               "",
+               "\u00e0k\u00f3k\u00f2 \u00e0\u00e1r\u00edn gb\u00f9ngb\u00f9n",
+               "",
+            };
+        final String[] America_Mountain = new String[] {
+               "\u00c0k\u00f3k\u00f2 asiko \u00f2k\u00e8",
+               "",
+               "\u00c0k\u00f3k\u00f2 oj\u00fam\u0254m\u0254 Ori-\u00f2k\u00e8",
+               "",
+               "\u00c0k\u00f3k\u00f2 \u00f2k\u00e8",
+               "",
+            };
         final String[] America_Pacific = new String[] {
                "\u00c0k\u00f3k\u00f2 \u00e0sik\u00f2 P\u00e0s\u00edf\u00ed\u00eck\u00ec",
                "",
@@ -118,30 +134,6 @@ public class TimeZoneNames_yo_BJ extends TimeZoneNamesBundle {
                "\u00c0k\u00f3k\u00f2 \u00c0t\u00ecl\u00e1\u0144t\u00ed\u00eck\u00ec",
                "",
             };
-        final String[] GMT = new String[] {
-               "Greenwich Mean Time",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] America_Central = new String[] {
-               "\u00e0k\u00f3k\u00f2 asiko \u00e0\u00e1r\u00edn gb\u00f9ngb\u00f9n",
-               "",
-               "Ak\u00f3k\u00f2 \u00e0\u00e1r\u00edn gb\u00f9ngb\u00f9n oj\u00fam\u0254m\u0254",
-               "",
-               "\u00e0k\u00f3k\u00f2 \u00e0\u00e1r\u00edn gb\u00f9ngb\u00f9n",
-               "",
-            };
-        final String[] America_Mountain = new String[] {
-               "\u00c0k\u00f3k\u00f2 asiko \u00f2k\u00e8",
-               "",
-               "\u00c0k\u00f3k\u00f2 oj\u00fam\u0254m\u0254 Ori-\u00f2k\u00e8",
-               "",
-               "\u00c0k\u00f3k\u00f2 \u00f2k\u00e8",
-               "",
-            };
         final Object[][] data = new Object[][] {
             { "America/Los_Angeles", America_Pacific },
             { "America/Denver", America_Mountain },
@@ -151,7 +143,6 @@ public class TimeZoneNames_yo_BJ extends TimeZoneNamesBundle {
             { "America/Indianapolis", America_Eastern },
             { "America/Halifax", Atlantic },
             { "Europe/Paris", Europe_Central },
-            { "GMT", GMT },
             { "Africa/Casablanca",
                 new String[] {
                     "",
@@ -173,10 +164,14 @@ public class TimeZoneNames_yo_BJ extends TimeZoneNamesBundle {
                     "",
                 }
             },
+            { "Europe/Ljubljana", Europe_Central },
+            { "America/Thule", Atlantic },
+            { "America/Curacao", Atlantic },
             { "America/Marigot", Atlantic },
+            { "America/Martinique", Atlantic },
+            { "Europe/Berlin", Europe_Central },
             { "America/El_Salvador", America_Central },
             { "America/Kentucky/Monticello", America_Eastern },
-            { "Africa/Ouagadougou", GMT },
             { "America/Coral_Harbour", America_Eastern },
             { "Africa/El_Aaiun",
                 new String[] {
@@ -192,137 +187,26 @@ public class TimeZoneNames_yo_BJ extends TimeZoneNamesBundle {
             { "America/Aruba", Atlantic },
             { "America/North_Dakota/Center", America_Central },
             { "America/Guatemala", America_Central },
-            { "Europe/London", GMT },
-            { "America/Cayman", America_Eastern },
-            { "America/Belize", America_Central },
-            { "America/Panama", America_Eastern },
-            { "Europe/San_Marino", Europe_Central },
-            { "America/Indiana/Tell_City", America_Central },
-            { "America/Tijuana", America_Pacific },
-            { "America/Managua", America_Central },
-            { "America/Indiana/Petersburg", America_Eastern },
-            { "Europe/Brussels", Europe_Central },
-            { "America/Ojinaga", America_Mountain },
-            { "Europe/Warsaw", Europe_Central },
-            { "Europe/Jersey", GMT },
-            { "America/Tegucigalpa", America_Central },
-            { "Asia/Damascus", Europe_Eastern },
-            { "Europe/Luxembourg", Europe_Central },
-            { "Atlantic/Reykjavik", GMT },
-            { "Europe/Zaporozhye", Europe_Eastern },
-            { "Atlantic/St_Helena", GMT },
-            { "Europe/Guernsey", GMT },
-            { "Atlantic/Madeira", Europe_Western },
-            { "Antarctica/Palmer",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "America/Thunder_Bay", America_Eastern },
-            { "America/Grand_Turk", America_Eastern },
-            { "Europe/Uzhgorod", Europe_Eastern },
-            { "America/Indiana/Marengo", America_Eastern },
-            { "America/Creston", America_Mountain },
-            { "America/Punta_Arenas",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "Europe/Isle_of_Man", GMT },
-            { "America/Mexico_City", America_Central },
-            { "Africa/Tunis", Europe_Central },
-            { "Europe/Andorra", Europe_Central },
-            { "Africa/Tripoli", Europe_Eastern },
-            { "Africa/Banjul", GMT },
-            { "America/Matamoros", America_Central },
-            { "America/Blanc-Sablon", Atlantic },
-            { "Europe/Kaliningrad", Europe_Eastern },
-            { "Europe/Lisbon", Europe_Western },
-            { "Europe/Oslo", Europe_Central },
-            { "Etc/GMT", GMT },
-            { "CST6CDT", America_Central },
-            { "Atlantic/Canary", Europe_Western },
-            { "Africa/Lome", GMT },
-            { "America/Menominee", America_Central },
-            { "Africa/Freetown", GMT },
-            { "Europe/Malta", Europe_Central },
-            { "America/Resolute", America_Central },
-            { "Europe/Busingen", Europe_Central },
-            { "SystemV/EST5", America_Eastern },
-            { "Europe/Skopje", Europe_Central },
-            { "America/Edmonton", America_Mountain },
-            { "Europe/Podgorica", Europe_Central },
-            { "Europe/Sarajevo", Europe_Central },
-            { "America/Santo_Domingo", Atlantic },
-            { "America/Glace_Bay", Atlantic },
-            { "Europe/Kiev", Europe_Eastern },
-            { "Europe/Rome", Europe_Central },
-            { "America/Port-au-Prince", America_Eastern },
-            { "Europe/Belfast", GMT },
-            { "America/St_Barthelemy", Atlantic },
-            { "America/Nipigon", America_Eastern },
-            { "America/Regina", America_Central },
-            { "Atlantic/Jan_Mayen", Europe_Central },
-            { "America/Dawson_Creek", America_Mountain },
-            { "Africa/Algiers", Europe_Central },
-            { "Europe/Mariehamn", Europe_Eastern },
-            { "America/St_Thomas", Atlantic },
-            { "Europe/Zurich", Europe_Central },
-            { "America/Anguilla", Atlantic },
-            { "Europe/Vilnius", Europe_Eastern },
-            { "Africa/Bamako", GMT },
-            { "Europe/Saratov",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "America/Cancun", America_Eastern },
-            { "Europe/Gibraltar", Europe_Central },
-            { "Africa/Conakry", GMT },
-            { "America/St_Lucia", Atlantic },
-            { "Europe/Madrid", Europe_Central },
-            { "America/Bahia_Banderas", America_Central },
-            { "America/Montserrat", Atlantic },
-            { "America/Cambridge_Bay", America_Mountain },
-            { "Europe/Vaduz", Europe_Central },
-            { "America/Barbados", Atlantic },
-            { "America/Louisville", America_Eastern },
-            { "America/Lower_Princes", Atlantic },
-            { "America/Vancouver", America_Pacific },
-            { "America/Danmarkshavn", GMT },
-            { "America/Detroit", America_Eastern },
-            { "Europe/Ljubljana", Europe_Central },
-            { "America/Thule", Atlantic },
-            { "America/Curacao", Atlantic },
-            { "America/Martinique", Atlantic },
-            { "Europe/Berlin", Europe_Central },
             { "Europe/Chisinau", Europe_Eastern },
             { "America/Puerto_Rico", Atlantic },
             { "America/Rankin_Inlet", America_Central },
+            { "America/Cayman", America_Eastern },
+            { "America/Belize", America_Central },
+            { "America/Panama", America_Eastern },
             { "Europe/Stockholm", Europe_Central },
-            { "Africa/Dakar", GMT },
             { "SystemV/CST6CDT", America_Central },
             { "America/Tortola", Atlantic },
             { "Europe/Budapest", Europe_Central },
+            { "Europe/San_Marino", Europe_Central },
+            { "America/Indiana/Tell_City", America_Central },
+            { "America/Tijuana", America_Pacific },
             { "Europe/Zagreb", Europe_Central },
             { "America/Port_of_Spain", Atlantic },
+            { "America/Managua", America_Central },
             { "Europe/Helsinki", Europe_Eastern },
             { "Asia/Beirut", Europe_Eastern },
+            { "America/Indiana/Petersburg", America_Eastern },
+            { "Europe/Brussels", Europe_Central },
             { "Pacific/Bougainville",
                 new String[] {
                     "",
@@ -333,13 +217,17 @@ public class TimeZoneNames_yo_BJ extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "Africa/Sao_Tome", GMT },
+            { "America/Ojinaga", America_Mountain },
+            { "Europe/Warsaw", Europe_Central },
             { "Europe/Tallinn", Europe_Eastern },
+            { "America/Tegucigalpa", America_Central },
+            { "Asia/Damascus", Europe_Eastern },
+            { "Europe/Luxembourg", Europe_Central },
             { "America/Rainy_River", America_Central },
             { "Europe/Belgrade", Europe_Central },
-            { "Africa/Bissau", GMT },
             { "SystemV/AST4", Atlantic },
             { "America/Yellowknife", America_Mountain },
+            { "Europe/Zaporozhye", Europe_Eastern },
             { "Europe/Astrakhan",
                 new String[] {
                     "",
@@ -352,26 +240,58 @@ public class TimeZoneNames_yo_BJ extends TimeZoneNamesBundle {
             },
             { "America/Indiana/Vevay", America_Eastern },
             { "Africa/Ceuta", Europe_Central },
-            { "Africa/Timbuktu", GMT },
+            { "Atlantic/Madeira", Europe_Western },
+            { "Antarctica/Palmer",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "America/Goose_Bay", Atlantic },
+            { "America/Thunder_Bay", America_Eastern },
             { "America/Swift_Current", America_Central },
+            { "America/Grand_Turk", America_Eastern },
+            { "Europe/Uzhgorod", Europe_Eastern },
             { "America/Pangnirtung", America_Eastern },
+            { "America/Indiana/Marengo", America_Eastern },
             { "Europe/Sofia", Europe_Eastern },
-            { "Africa/Nouakchott", GMT },
+            { "America/Creston", America_Mountain },
+            { "America/Punta_Arenas",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "Europe/Prague", Europe_Central },
             { "America/Indiana/Vincennes", America_Eastern },
             { "America/Whitehorse", America_Pacific },
             { "America/Kralendijk", Atlantic },
-            { "Antarctica/Troll", GMT },
+            { "America/Mexico_City", America_Central },
+            { "Africa/Tunis", Europe_Central },
             { "America/Antigua", Atlantic },
+            { "Europe/Andorra", Europe_Central },
+            { "Africa/Tripoli", Europe_Eastern },
             { "America/Montreal", America_Eastern },
             { "America/Inuvik", America_Mountain },
             { "America/Iqaluit", America_Eastern },
+            { "America/Matamoros", America_Central },
             { "Asia/Nicosia", Europe_Eastern },
             { "America/Moncton", Atlantic },
+            { "America/Blanc-Sablon", Atlantic },
+            { "Europe/Kaliningrad", Europe_Eastern },
             { "America/Indiana/Winamac", America_Eastern },
             { "SystemV/MST7MDT", America_Mountain },
+            { "Europe/Lisbon", Europe_Western },
             { "America/St_Vincent", Atlantic },
+            { "Europe/Oslo", Europe_Central },
             { "Asia/Gaza", Europe_Eastern },
             { "PST8PDT", America_Pacific },
             { "timezone.excity.Etc/Unknown", "\u00ccl\u00fa \u00c0\u00ecm\u0254\u0300" },
@@ -387,9 +307,14 @@ public class TimeZoneNames_yo_BJ extends TimeZoneNamesBundle {
                     "",
                 }
             },
+            { "CST6CDT", America_Central },
+            { "Atlantic/Canary", Europe_Western },
             { "Europe/Bratislava", Europe_Central },
+            { "America/Menominee", America_Central },
             { "Europe/Copenhagen", Europe_Central },
+            { "Europe/Malta", Europe_Central },
             { "Europe/Vienna", Europe_Central },
+            { "America/Resolute", America_Central },
             { "Europe/Ulyanovsk",
                 new String[] {
                     "",
@@ -400,19 +325,32 @@ public class TimeZoneNames_yo_BJ extends TimeZoneNamesBundle {
                     "",
                 }
             },
+            { "Europe/Busingen", Europe_Central },
+            { "SystemV/EST5", America_Eastern },
             { "America/Merida", America_Central },
+            { "Europe/Skopje", Europe_Central },
+            { "America/Edmonton", America_Mountain },
+            { "Europe/Podgorica", Europe_Central },
+            { "Europe/Sarajevo", Europe_Central },
             { "Europe/Tirane", Europe_Central },
+            { "America/Santo_Domingo", Atlantic },
             { "SystemV/MST7", America_Mountain },
             { "America/St_Kitts", Atlantic },
             { "Arctic/Longyearbyen", Europe_Central },
             { "America/Fort_Nelson", America_Mountain },
             { "Europe/Riga", Europe_Eastern },
+            { "America/Glace_Bay", Atlantic },
             { "America/Dominica", Atlantic },
             { "America/Guadeloupe", Atlantic },
+            { "Europe/Kiev", Europe_Eastern },
+            { "Europe/Rome", Europe_Central },
             { "Asia/Hebron", Europe_Eastern },
             { "SystemV/PST8PDT", America_Pacific },
-            { "Africa/Abidjan", GMT },
-            { "Africa/Monrovia", GMT },
+            { "America/Port-au-Prince", America_Eastern },
+            { "America/St_Barthelemy", Atlantic },
+            { "America/Nipigon", America_Eastern },
+            { "America/Regina", America_Central },
+            { "Atlantic/Jan_Mayen", Europe_Central },
             { "Asia/Srednekolymsk",
                 new String[] {
                     "",
@@ -426,16 +364,34 @@ public class TimeZoneNames_yo_BJ extends TimeZoneNamesBundle {
             { "America/Boise", America_Mountain },
             { "EST5EDT", America_Eastern },
             { "America/North_Dakota/New_Salem", America_Central },
+            { "America/Dawson_Creek", America_Mountain },
+            { "Africa/Algiers", Europe_Central },
+            { "Europe/Mariehamn", Europe_Eastern },
+            { "America/St_Thomas", Atlantic },
+            { "Europe/Zurich", Europe_Central },
             { "Atlantic/Bermuda", Atlantic },
+            { "America/Anguilla", Atlantic },
             { "America/Costa_Rica", America_Central },
             { "America/Dawson", America_Pacific },
+            { "Europe/Vilnius", Europe_Eastern },
             { "America/Shiprock", America_Mountain },
             { "America/Winnipeg", America_Central },
             { "Europe/Amsterdam", Europe_Central },
+            { "Europe/Saratov",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "America/Indiana/Knox", America_Central },
+            { "America/Cancun", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "Europe/Vatican", Europe_Central },
-            { "Africa/Accra", GMT },
+            { "Europe/Gibraltar", Europe_Central },
             { "Asia/Amman", Europe_Eastern },
             { "Etc/UTC",
                 new String[] {
@@ -448,14 +404,24 @@ public class TimeZoneNames_yo_BJ extends TimeZoneNamesBundle {
                 }
             },
             { "SystemV/AST4ADT", Atlantic },
-            { "Europe/Dublin", GMT },
+            { "America/St_Lucia", Atlantic },
+            { "Europe/Madrid", Europe_Central },
+            { "America/Bahia_Banderas", America_Central },
+            { "America/Montserrat", Atlantic },
+            { "America/Cambridge_Bay", America_Mountain },
             { "America/Toronto", America_Eastern },
+            { "Europe/Vaduz", Europe_Central },
             { "MST7MDT", America_Mountain },
+            { "America/Barbados", Atlantic },
             { "America/Monterrey", America_Central },
             { "SystemV/EST5EDT", America_Eastern },
             { "America/Nassau", America_Eastern },
             { "America/Jamaica", America_Eastern },
+            { "America/Louisville", America_Eastern },
+            { "America/Lower_Princes", Atlantic },
+            { "America/Vancouver", America_Pacific },
             { "Europe/Athens", Europe_Eastern },
+            { "America/Detroit", America_Eastern },
             { "SystemV/CST6", America_Central },
             { "Europe/Monaco", Europe_Central },
         };
