@@ -87,7 +87,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
                "",
             };
         final String[] Magadan = new String[] {
-               "Isikhathi Esimisiwe sase-Magadan",
+               "Isikhathi Esivamile sase-Magadan",
                "",
                "Isikhathi sasehlobo e-Magadan",
                "",
@@ -135,7 +135,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
                "",
             };
         final String[] Yakutsk = new String[] {
-               "Isikhathi Esimisiwe sase-Yakutsk",
+               "Isikhathi Esivamile sase-Yakutsk",
                "",
                "Isikhathi sasehlobo e-Yakutsk",
                "",
@@ -207,7 +207,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
                "",
             };
         final String[] Yekaterinburg = new String[] {
-               "Isikhathi Esimisiwe sase-Yekaterinburg",
+               "Isikhathi Esivamile sase-Yekaterinburg",
                "",
                "Isikhathi sasehlobo e-Yekaterinburg",
                "",
@@ -239,7 +239,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
                "",
             };
         final String[] Africa_Southern = new String[] {
-               "Isikhathi esijwayelekile saseNingizimu Afrika",
+               "Isikhathi esivamile saseNingizimu Afrika",
                "",
                "",
                "",
@@ -439,7 +439,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
                "",
             };
         final String[] Samoa = new String[] {
-               "Isikhathi sase-Samoa esijwayelekile",
+               "Isikhathi sase-Samoa esivamile",
                "",
                "Isikhathi sase-Samoa sasemini",
                "",
@@ -487,7 +487,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
                "",
             };
         final String[] New_Caledonia = new String[] {
-               "Isikhathi sase-New Caledonia esijwayelekile",
+               "Isikhathi sase-New Caledonia esivamile",
                "",
                "Isikhathi sase-New Caledonia sasehlobo",
                "",
@@ -519,7 +519,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
                "",
             };
         final String[] Tonga = new String[] {
-               "Isikhathi sase-Tonga esijwayelekile",
+               "Isikhathi sase-Tonga esivamile",
                "",
                "Isikhathi sase-Tonga sasehlobo",
                "",
@@ -535,7 +535,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
                "",
             };
         final String[] Peru = new String[] {
-               "Isikhathi sase-Peru esijwayelekile",
+               "Isikhathi sase-Peru esivamile",
                "",
                "Isikhathi sase-Peru sasehlobo",
                "",
@@ -607,7 +607,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
                "",
             };
         final String[] Irkutsk = new String[] {
-               "Isikhathi Esimisiwe sase-Irkutsk",
+               "Isikhathi Esivamile sase-Irkutsk",
                "",
                "Isikhathi sasehlobo e-Irkutsk",
                "",
@@ -623,7 +623,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
                "",
             };
         final String[] Choibalsan = new String[] {
-               "Isikhathi Esimisiwe sase-Choibalsan",
+               "Isikhathi Esivamile sase-Choibalsan",
                "",
                "Isikhathi sehlobo e-Choibalsan",
                "",
@@ -639,7 +639,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
                "",
             };
         final String[] Armenia = new String[] {
-               "Isikhathi esezingeni sase-Armenia",
+               "Isikhathi esivamile sase-Armenia",
                "",
                "Isikhathi sehlobo sase-Armenia",
                "",
@@ -687,7 +687,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
                "",
             };
         final String[] Sakhalin = new String[] {
-               "Isikhathi Esimisiwe sase-Sakhalin",
+               "Isikhathi Esivamile sase-Sakhalin",
                "",
                "Isikhathi sasehlobo e-Sakhalin",
                "",
@@ -695,7 +695,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
                "",
             };
         final String[] Paraguay = new String[] {
-               "Isikhathi sase-Paraguay esijwayelekile",
+               "Isikhathi sase-Paraguay esivamile",
                "",
                "Isikhathi sase-Paraguay sasehlobo",
                "",
@@ -791,7 +791,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
                "",
             };
         final String[] Omsk = new String[] {
-               "Isikhathi Esimisiwe sase-Omsk",
+               "Isikhathi Esivamile sase-Omsk",
                "",
                "Isikhathi sasehlobo sase-Omsk",
                "",
@@ -839,7 +839,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
                "",
             };
         final String[] Novosibirsk = new String[] {
-               "Isikhathi Esimisiwe sase-Novosibirsk",
+               "Isikhathi Esivamile sase-Novosibirsk",
                "",
                "Isikhathi sasehlobo sase-Novosibirsk",
                "",
@@ -871,7 +871,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
                "",
             };
         final String[] Krasnoyarsk = new String[] {
-               "Isikhathi Esimisiwe sase-Krasnoyarsk",
+               "Isikhathi Esivamile sase-Krasnoyarsk",
                "",
                "Isikhathi sasehlobo e-Krasnoyarsk",
                "",
@@ -1031,7 +1031,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
                "",
             };
         final String[] Africa_Western = new String[] {
-               "Isikhathi esijwayelekile saseNtshonalanga Afrika",
+               "Isikhathi esivamile saseNtshonalanga Afrika",
                "",
                "Isikhathi sasehlobo saseNtshonalanga Afrika",
                "",
@@ -1047,7 +1047,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
                "",
             };
         final String[] Volgograd = new String[] {
-               "Isikhathi Esimisiwe sase-Volgograd",
+               "Isikhathi Esivamile sase-Volgograd",
                "",
                "Isikhathi sase-Volgograd sasehlobo",
                "",
@@ -1103,7 +1103,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
                "",
             };
         final String[] Korea = new String[] {
-               "Isikhathi esisezengeni sase-Korea",
+               "Isikhathi Esivamile sase-Korea",
                "",
                "Isikhathi semini sase-Korea",
                "",
@@ -1159,7 +1159,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
                "",
             };
         final String[] Vladivostok = new String[] {
-               "Isikhathi Esimisiwe sase-Vladivostok",
+               "Isikhathi Esivamile sase-Vladivostok",
                "",
                "Isikhathi sasehlobo e-Vladivostok",
                "",
@@ -1167,7 +1167,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
                "",
             };
         final String[] Chamorro = new String[] {
-               "Isikhathi esijwayelekile sase-Chamorro",
+               "Isikhathi esivamile sase-Chamorro",
                "",
                "",
                "",
@@ -1191,7 +1191,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
                "",
             };
         final String[] Noronha = new String[] {
-               "Isikhathi sase-Fernando de Noronha esijwayelekile",
+               "Isikhathi sase-Fernando de Noronha esivamile",
                "",
                "Isikhathi sase-Fernando de Noronha sasehlobo",
                "",
@@ -1354,7 +1354,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             { "Africa/Malabo", Africa_Western },
             { "America/Catamarca", Argentina },
             { "America/Godthab", Greenland_Western },
-            { "timezone.excity.America/St_Lucia", "i-" },
+            { "timezone.excity.America/St_Lucia", "I-St. Lucia" },
             { "timezone.excity.Asia/Novokuznetsk", "i-Novokuznetsk" },
             { "timezone.excity.Europe/Berlin", "i-Berlin" },
             { "Africa/Lagos", Africa_Western },
@@ -1443,7 +1443,6 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             { "Australia/Adelaide", Australia_Central },
             { "timezone.excity.America/Lima", "i-Lima" },
             { "timezone.excity.America/North_Dakota/New_Salem", "i-New Salem, North Dakota" },
-            { "timezone.excity.Asia/Atyrau", "Atyrau" },
             { "America/Paramaribo", Suriname },
             { "timezone.excity.Asia/Bishkek", "i-Bishkek" },
             { "America/Indiana/Vincennes", America_Eastern },
@@ -1716,7 +1715,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Thimphu", Bhutan },
             { "Asia/Rangoon", Myanmar },
-            { "timezone.excity.Indian/Christmas", "i-Christmas" },
+            { "timezone.excity.Indian/Christmas", "Ukhisimusi" },
             { "Asia/Calcutta", India },
             { "America/Argentina/Tucuman", Argentina },
             { "Asia/Kabul", Afghanistan },
@@ -1731,6 +1730,7 @@ public class TimeZoneNames_zu extends TimeZoneNamesBundle {
             { "America/Caracas", Venezuela },
             { "Asia/Hebron", Europe_Eastern },
             { "SystemV/PST8PDT", America_Pacific },
+            { "timezone.excity.Asia/Qostanay", "I-Kostanay" },
             { "Africa/Monrovia", GMT },
             { "Asia/Ust-Nera", Vladivostok },
             { "timezone.excity.America/Louisville", "i-Louisville" },
